@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2004,2007 Free Software Foundation, Inc.
+   Copyright (C) 2004-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <radius/radius.h>
 #include <sysdep.h>
@@ -28,9 +27,10 @@
 #include <radius/argcv.h>
 #include <radius/debug.h>
 #include <pwd.h>
+#include <stdio.h>
 
 #define obstack_chunk_alloc grad_emalloc
-#define obstack_chunk_free grad_free
+#define obstack_chunk_free free
 #include <obstack.h>
 
 #include <regex.h>
@@ -40,13 +40,14 @@
 #define _(s) gettext(s)
 #define N_(s) gettext_noop(s)
 
-typedef grad_uint32_t grad_counter_t;
+typedef uint32_t grad_counter_t;
 
 char *grad_readline(char *prompt);
 void grad_add_history (char *line);
-int grad_read_history_file();
-int grad_write_history_file();
+int grad_read_history_file(void);
+int grad_write_history_file(void);
 void grad_readline_init(char *name,
 			int interactive,
-			char **(*completion_fp)(char *cmd,
+			char **(*completion_fp)(const char *cmd,
 						int start, int end));
+void grad_readline_set_input(FILE *fp);
