@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006,2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -15,27 +14,22 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifndef _gnu_radius_radius_h
 #define _gnu_radius_radius_h
 
-#include <radius/types.h>
+#include <stdarg.h>
+#include <stdio.h>
+#include <stdint.h>
+#include <sys/time.h>
+#include <time.h>
+
+#include <radius/version.h>
 #include <radius/list.h>
 #include <radius/envar.h>
 #include <radius/mem.h>
 #include <radius/dictionary.h>
-#include <stdarg.h>
-
-#ifdef HAVE_SYS_TIME_H
-# include <sys/time.h>
-# ifdef TIME_WITH_SYS_TIME
-#  include <time.h>
-# endif
-#else
-# include <time.h>
-#endif
 
 /* Length of an IPv4 address in 'dotted-quad' representation including
    null terminator */
@@ -171,20 +165,20 @@ typedef struct {
 } grad_locus_t;
 
 typedef struct {
-	grad_uint32_t addr;     /* Server IP address */
+	uint32_t addr;     /* Server IP address */
 	u_char id;              /* Current id */
 } grad_server_id_t;
 
 typedef struct netdef grad_netdef_t;
 struct netdef {
-        grad_uint32_t ipaddr;        /* IP address */
-        grad_uint32_t netmask;       /* Network mask */
+        uint32_t ipaddr;        /* IP address */
+        uint32_t netmask;       /* Network mask */
 };
 
 typedef struct radius_server grad_server_t;
 struct radius_server {
         char   *name;           /* Symbolic name of this server */
-        grad_uint32_t addr;     /* IP address of it */
+        uint32_t addr;     /* IP address of it */
         int    port[GRAD_PORT_MAX];  /* Ports to use */
         char   *secret;         /* Shared secret */
 	off_t  id_offset;       /* Offset of the grad_server_id_t in the id
@@ -192,7 +186,7 @@ struct radius_server {
 };
 
 typedef struct {
-        grad_uint32_t source_ip; /* Source IP address for xmits */
+        uint32_t source_ip; /* Source IP address for xmits */
         unsigned timeout;        /* Amount of time to wait for the response */
         unsigned retries;        /* Number of re-sends to each server before
 				    giving up */
@@ -245,7 +239,7 @@ typedef struct grad_string {
 } grad_string_t;
 
 typedef union grad_datum {
-	grad_uint32_t   ival;       /* integer value */
+	uint32_t   ival;       /* integer value */
 	grad_string_t   sval;       /* string value */
 } grad_datum_t;
 
@@ -282,13 +276,13 @@ typedef struct grad_realm {
 } grad_realm_t;
 
 typedef struct grad_request {
-        grad_uint32_t ipaddr;       /* Source IP address */
+        uint32_t ipaddr;       /* Source IP address */
         u_short       udp_port;     /* Source port */
         u_char        id;           /* Request identifier */
         u_char        code;         /* Request code */
         u_char        authenticator[GRAD_AUTHENTICATOR_LENGTH];
 	                            /* Request authenticator */
-        u_char        *secret;      /* Shared secret */
+        char          *secret;      /* Shared secret */
         grad_avp_t    *avlist;      /* Request pairs */
 } grad_request_t;
 
@@ -323,16 +317,16 @@ extern int grad_source_info_option;
 extern grad_locus_t grad_parser_source_locus;
 
 int grad_parser_lex_init(char *name);
-void grad_parser_lex_finish();
-int grad_parser_lex_sync();
+void grad_parser_lex_finish(void);
+int grad_parser_lex_sync(void);
 
 #define GRAD_NITEMS(a) sizeof(a)/sizeof((a)[0])
 
 size_t grad_create_pdu(void **rptr, int code, int id,
-		       u_char *authenticator, u_char *secret,
+		       u_char *authenticator, char *secret,
 		       grad_avp_t *pairlist, char *msg);
 
-grad_request_t *grad_decode_pdu(grad_uint32_t host,
+grad_request_t *grad_decode_pdu(uint32_t host,
 				u_short udp_port, u_char *buffer,
 				size_t length);
 
@@ -353,7 +347,7 @@ void grad_dict_free();
 grad_dict_attr_t *grad_attr_number_to_dict(int);
 grad_dict_attr_t *grad_attr_name_to_dict(const char *);
 grad_dict_value_t *grad_value_name_to_value(const char *, int);
-grad_dict_value_t *grad_value_lookup(grad_uint32_t, char *);
+grad_dict_value_t *grad_value_lookup(uint32_t, char *);
 int grad_vendor_id_to_pec(int);
 int grad_vendor_pec_to_id(int);
 char *grad_vendor_pec_to_name(int);
@@ -384,7 +378,7 @@ grad_avp_t *grad_avl_dup(grad_avp_t *from);
 grad_avp_t *grad_avp_dup(grad_avp_t *vp);
 void grad_avl_merge(grad_avp_t **dst_ptr, grad_avp_t **src_ptr);
 grad_avp_t *grad_avp_create(int attr);
-grad_avp_t *grad_avp_create_integer(int attr, grad_uint32_t value);
+grad_avp_t *grad_avp_create_integer(int attr, uint32_t value);
 grad_avp_t *grad_avp_create_string(int attr, char *value);
 grad_avp_t *grad_avp_create_binary(int attr, int length, u_char *value);
 void grad_avl_move_attr(grad_avp_t **to, grad_avp_t **from, int attr);
@@ -394,30 +388,32 @@ int grad_avp_cmp(grad_avp_t *a, grad_avp_t *b);
 int grad_avl_cmp(grad_avp_t *a, grad_avp_t *b, int prop);
 int grad_avp_null_string_p(grad_avp_t *pair);
 	
+void grad_avl_fprint(FILE *fp, char *prefix, int typeflag, grad_avp_t *avl);
+
 extern int grad_resolve_hostnames;
 
-char *grad_ip_gethostname (grad_uint32_t, char *buf, size_t size);
-grad_uint32_t grad_ip_gethostaddr (const char *);
-char *grad_ip_iptostr(grad_uint32_t, char *);
-grad_uint32_t grad_ip_strtoip(const char *);
+char *grad_ip_gethostname (uint32_t, char *buf, size_t size);
+uint32_t grad_ip_gethostaddr (const char *);
+char *grad_ip_iptostr(uint32_t, char *);
+uint32_t grad_ip_strtoip(const char *);
 int grad_ip_getnetaddr(const char *str, grad_netdef_t *netdef);
-int grad_ip_in_net_p(const grad_netdef_t *netdef, grad_uint32_t ipaddr);
+int grad_ip_in_net_p(const grad_netdef_t *netdef, uint32_t ipaddr);
 
 /* nas.c */
 grad_iterator_t *grad_nas_iterator();
 int grad_nas_read_file(char *file);
 grad_nas_t *grad_nas_lookup_name(char *name);
-grad_nas_t *grad_nas_lookup_ip(grad_uint32_t ipaddr);
-char *grad_nas_ip_to_name(grad_uint32_t ipaddr, char *buf, size_t size);
+grad_nas_t *grad_nas_lookup_ip(uint32_t ipaddr);
+char *grad_nas_ip_to_name(uint32_t ipaddr, char *buf, size_t size);
 grad_nas_t *grad_nas_request_to_nas(const grad_request_t *radreq);
 char *grad_nas_request_to_name(const grad_request_t *radreq, char *buf, size_t size);
 
 /* realms.c */
 grad_realm_t *grad_realm_lookup_name(char *name);
-grad_realm_t *grad_realm_lookup_ip(grad_uint32_t ip);
+grad_realm_t *grad_realm_lookup_ip(uint32_t ip);
 int grad_read_realms(char *filename, int auth_port, int acct_port,
-		     int (*set_secret)());
-int grad_realm_verify_ip(grad_realm_t *realm, grad_uint32_t ip);
+		     int (*set_secret)(grad_server_t *));
+int grad_realm_verify_ip(grad_realm_t *realm, uint32_t ip);
 int grad_realm_strip_p(grad_realm_t *r);
 size_t grad_realm_get_quota(grad_realm_t *r);
 grad_request_t *grad_request_alloc();
@@ -436,6 +432,8 @@ typedef int (*register_rule_fp) (void *, grad_locus_t *, char *,
 				 grad_avp_t *, grad_avp_t *);
 int grad_parse_rule_file(char *file, void *c, register_rule_fp f);
 int grad_parse_time_string(char *valstr, struct tm *tm);
+unsigned long grad_julianday(int year, int month, int day);
+time_t grad_tm_to_epoch(struct tm *tm);
 grad_avp_t *grad_create_pair(grad_locus_t *loc, char *name,
 			     enum grad_operator op, char *valstr);
 
@@ -465,16 +463,16 @@ int grad_c_strncasecmp(const char *a, const char *b, size_t n);
 
 /* cryptpass.c */
 void grad_encrypt_password(grad_avp_t *pair, char *password,
-			   char *authenticator, char *secret);
+			   u_char *authenticator, char *secret);
 void grad_decrypt_password(char *password, grad_avp_t *pair,
-			   char *authenticator, char *secret);
+			   u_char *authenticator, char *secret);
 void grad_decrypt_password_broken(char *password, grad_avp_t *pair,
-				  char *authenticator, char *secret);
+				  u_char *authenticator, char *secret);
 void grad_encrypt_tunnel_password(grad_avp_t *pair, u_char tag, char *password,
-				  char *authenticator, char *secret);
+				  u_char *authenticator, char *secret);
 void grad_decrypt_tunnel_password(char *password, u_char *tag,
 				  grad_avp_t *pair,
-				  char *authenticator, char *secret);
+				  u_char *authenticator, char *secret);
 
 /* gethost_r.c */
 struct hostent *grad_gethostbyname_r(const char *name, struct hostent *result,
@@ -500,7 +498,7 @@ grad_request_t *grad_client_send(grad_server_queue_t *config,
 				 grad_avp_t *pairlist);
 unsigned grad_client_message_id(grad_server_t *server);
 grad_server_queue_t *grad_client_create_queue(int read_cfg,
-					      grad_uint32_t source_ip,
+					      uint32_t source_ip,
 					      size_t bufsize);
 void grad_client_destroy_queue(grad_server_queue_t *queue);
 grad_server_t *grad_client_alloc_server(grad_server_t *src);
@@ -510,11 +508,11 @@ void grad_client_free_server(grad_server_t *server);
 void grad_client_append_server(grad_server_queue_t *qp, grad_server_t *server);
 void grad_client_clear_server_list(grad_server_queue_t *qp);
 grad_server_t *grad_client_find_server(grad_server_queue_t *qp, char *name);
-void grad_client_random_authenticator(char *authenticator);
+void grad_client_random_authenticator(u_char *authenticator);
 grad_avp_t *grad_client_encrypt_pairlist(grad_avp_t *plist,
-					 u_char *authenticator, u_char *secret);
+					 u_char *authenticator, char *secret);
 grad_avp_t *grad_client_decrypt_pairlist(grad_avp_t *plist,
-					 u_char *authenticator, u_char *secret);
+					 u_char *authenticator, char *secret);
 
 /* log.c */
 char *rad_print_request(grad_request_t *req, char *outbuf, size_t size);
@@ -586,7 +584,7 @@ void grad_log_loc(int lvl, grad_locus_t *loc, const char *msg, ...);
 /* sysdep.h */
 int grad_set_nonblocking(int fd);
 int grad_max_fd();
-grad_uint32_t grad_first_ip();
+uint32_t grad_first_ip();
 
 /* Loadable Modules Suppert */
 #define __s_cat3__(a,b,c) a ## b ## c
