@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifndef __radsnmp_h
 #define __radsnmp_h
@@ -61,7 +60,7 @@ typedef struct {
 struct nas_stat {
         struct nas_stat *next;
         int index;
-        grad_uint32_t ipaddr;
+        uint32_t ipaddr;
         grad_counter_t ports_active;
         grad_counter_t ports_idle;
         Auth_server_stat auth;
