@@ -1,6 +1,5 @@
-/*
-   This file is part of GNU Radius SNMP Library.
-   Copyright (C) 2001,2007 Free Software Foundation, Inc.
+/* This file is part of GNU Radius SNMP Library.
+   Copyright (C) 2001, 2007, 2010, 2013 Free Software Foundation, Inc.
    Written by Sergey Poznyakoff
 
    This library is free software; you can redistribute it and/or
@@ -13,10 +12,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 struct snmp_def {
         int req_id;
