@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2002,2003,2004,2005,2007 Free Software Foundation, Inc.
+   Copyright (C) 2002-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -13,10 +13,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public
-   License along with GNU Radius; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA. */
+   You should have received a copy of the GNU General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 /* Support for ascend binary filters. */
 
@@ -50,8 +48,8 @@ enum ascend_filter_cmp_op {
 
 /* The format of an IP filter attribute value. Fields are in netorder */
 typedef struct {
-	grad_uint32_t    src_ip;       /* The source IP address.  */
-	grad_uint32_t    dst_ip;       /* The destination IP address.  */
+	uint32_t    src_ip;       /* The source IP address.  */
+	uint32_t    dst_ip;       /* The destination IP address.  */
 	u_char   src_masklen;  /* The source netmask length */
 	u_char   dst_masklen;  /* The destination netmask length */
 	u_char   proto;        /* The IP protocol number */
@@ -67,7 +65,7 @@ typedef struct {
 /* IPX stuff. Not used at the moment */
 #define IPX_NODE_ADDR_LEN 6
 
-typedef grad_uint32_t   IPXADDR;
+typedef uint32_t   IPXADDR;
 typedef char    IPXNODE[IPX_NODE_ADDR_LEN];
 typedef u_short IPXSOCKET;
 
@@ -259,7 +257,7 @@ _get_hex_string(struct ascend_parse_buf *pb, u_char *buf)
 		}
 	}
 
-	for (i = 0; i < 2*ASCEND_MAX_CMP_LENGTH; i++)
+	for (i = 0; i < ASCEND_MAX_CMP_LENGTH; i += 2)
 		*buf++ = (tmp[i] << 4) | tmp[i+1];
 	return rc;
 }
@@ -380,7 +378,7 @@ _get_ip(struct ascend_parse_buf *pb)
 {
 	int dir = _get_direction_type(pb, "ip", 0);
 	char *tok;
-	grad_uint32_t ip, mask;
+	uint32_t ip, mask;
 	
 	if (dir == ASCEND_DIR_NONE)
 		return ASCEND_DIR_NONE;
@@ -668,7 +666,7 @@ grad_ascend_parse_filter(grad_avp_t *pair, char **errp)
 	
 	if (_ascend_parse_filter(pair->avp_strvalue, &flt, errp)) 
 		return 1;
-	grad_free(pair->avp_strvalue);
+	free(pair->avp_strvalue);
 	pair->avp_strlength = sizeof(flt);
 	pair->avp_strvalue = grad_emalloc(pair->avp_strlength);
 	memcpy(pair->avp_strvalue, &flt, sizeof(flt));
