@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006,2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
@@ -14,10 +13,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public
-   License along with GNU Radius; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA. */
+   You should have received a copy of the GNU General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -73,6 +70,8 @@ dict_symbol_ptr(DICT_SYMBOL *sym)
 	case dict_symbol_alias:
 		return sym->v.alias;
 	}
+	grad_insist_fail("unsupported symbol type");
+	return NULL;
 }
 
 static grad_dict_attr_t *
@@ -92,8 +91,8 @@ free_vendor(void *ptr, void *closure ARG_UNUSED)
 {
         grad_dict_vendor_t *vp = ptr;
         if (vp->vendorname)
-                grad_free(vp->vendorname);
-	grad_free(vp);
+                free(vp->vendorname);
+	free(vp);
 	return 0;
 }
 
@@ -101,13 +100,13 @@ static int
 free_value(void *ptr, void *closure ARG_UNUSED)
 {
         grad_dict_value_t *vp = ptr;
-        grad_free(vp->name);
-	grad_free(vp);
+        free(vp->name);
+	free(vp);
 	return 0;
 }
 
 void
-dict_free()
+dict_free(void)
 {
 	grad_symtab_free(&dict_attr_tab);
         memset(dict_attr_index, 0, sizeof dict_attr_index);
@@ -182,7 +181,7 @@ dict_register_parser(int attr, grad_attr_parser_fp fun)
 }
 
 static void
-parser_tab_init()
+parser_tab_init(void)
 {
 	if (!attr_parser_tab) {
 		/* Register ascend filters */
@@ -192,13 +191,13 @@ parser_tab_init()
 }	
 
 static void
-parser_tab_free()
+parser_tab_free(void)
 {
 	ATTR_PARSER_TAB *ep = attr_parser_tab;
 
 	while (ep) {
 		ATTR_PARSER_TAB *next = ep->next;
-		grad_free(ep);
+		free(ep);
 		ep = next;
 	}
 	attr_parser_tab = NULL;
@@ -841,12 +840,12 @@ parse_dict(char *name)
 		         dngettext(PACKAGE,
 				   "%s: %d error", "%s: %d errors",
 				   pd.errcnt), path, pd.errcnt);
-        grad_free(path);
+        free(path);
         return rc;
 }
 
 int
-grad_dict_init()
+grad_dict_init(void)
 {
 	parser_tab_free();
         dict_free();
@@ -858,7 +857,7 @@ grad_dict_init()
 }
 
 void
-grad_dict_free()
+grad_dict_free(void)
 {
 	parser_tab_free();
         dict_free();
@@ -958,7 +957,7 @@ valnum_cmp(const void *item, const void *data)
 }
 
 grad_dict_value_t *
-grad_value_lookup(grad_uint32_t value, char *attrname)
+grad_value_lookup(uint32_t value, char *attrname)
 {
         struct val_lookup data;
         data.number = value;
@@ -1050,8 +1049,6 @@ dict_iter_helper(void *data, grad_symbol_t *symbol)
 {
 	struct dict_iterator *p = data;
 	DICT_SYMBOL *dsym = (DICT_SYMBOL *) symbol;
-	grad_dict_attr_t *attr;
-
 	return p->fp(p->closure, dsym->name, dict_symbol_ptr(dsym));
 }
 	
