@@ -1,12 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public
-   License along with GNU Radius; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA. */
+   You should have received a copy of the GNU General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -70,11 +67,11 @@ good_ipaddr(const char *addr)
  *      for the supplied IP address.
  */
 char * 
-grad_ip_gethostname(grad_uint32_t ipaddr, char *namebuf, size_t size)
+grad_ip_gethostname(uint32_t ipaddr, char *namebuf, size_t size)
 {
         struct hostent *hp, hent;
         char buffer[512];
-        grad_uint32_t n_ipaddr;
+        uint32_t n_ipaddr;
         int h_err, len;
         
         n_ipaddr = htonl(ipaddr);
@@ -99,7 +96,7 @@ grad_ip_gethostname(grad_uint32_t ipaddr, char *namebuf, size_t size)
  * Return an IP address in host long notation from a host
  * name or address in dot notation.
  */
-grad_uint32_t 
+uint32_t 
 grad_ip_gethostaddr(const char *host)
 {
         struct hostent  *hp, hent;
@@ -112,7 +109,7 @@ grad_ip_gethostaddr(const char *host)
         hp = grad_gethostbyname_r(host, &hent, buffer, sizeof(buffer), &h_err);
         if (!hp)
                 return 0;
-        return ntohl(*(grad_uint32_t *)hp->h_addr);
+        return ntohl(*(uint32_t *)hp->h_addr);
 }
 
 /*
@@ -120,7 +117,7 @@ grad_ip_gethostaddr(const char *host)
  * provided address in host long notation.
  */
 char *
-grad_ip_iptostr(grad_uint32_t ipaddr, char *bufp)
+grad_ip_iptostr(uint32_t ipaddr, char *bufp)
 {
 	static char buffer[GRAD_IPV4_STRING_LENGTH];
 	if (!bufp)
@@ -137,7 +134,7 @@ grad_ip_iptostr(grad_uint32_t ipaddr, char *bufp)
  *      Return an IP address in host long notation from
  *      one supplied in standard dot notation.
  */
-grad_uint32_t 
+uint32_t 
 grad_ip_strtoip(const char *ip_str)
 #ifdef HAVE_INET_ATON
 {
@@ -153,31 +150,31 @@ grad_ip_strtoip(const char *ip_str)
         char    *ptr;
         int     i;
         int     count;
-        grad_uint32_t   ipaddr;
+        uint32_t   ipaddr;
         int     cur_byte;
 
-        ipaddr = (grad_uint32_t)0;
+        ipaddr = (uint32_t)0;
         for (i = 0; i < 4; i++) {
                 ptr = buf;
                 count = 0;
                 *ptr = '\0';
                 while (*ip_str != '.' && *ip_str != '\0' && count < 4) {
                         if (!isdigit(*ip_str)) {
-                                return((grad_uint32_t)0);
+                                return((uint32_t)0);
                         }
                         *ptr++ = *ip_str++;
                         count++;
                 }
                 if (count >= 4 || count == 0) {
-                        return((grad_uint32_t)0);
+                        return((uint32_t)0);
                 }
                 *ptr = '\0';
                 cur_byte = atoi(buf);
                 if (cur_byte < 0 || cur_byte > 255) {
-                        return((grad_uint32_t)0);
+                        return((uint32_t)0);
                 }
                 ip_str++;
-                ipaddr = ipaddr << 8 | (grad_uint32_t)cur_byte;
+                ipaddr = ipaddr << 8 | (uint32_t)cur_byte;
         }
         return ipaddr;
 }
@@ -204,7 +201,7 @@ grad_ip_getnetaddr(const char *str, grad_netdef_t *netdef)
 			netdef->netmask = grad_ip_strtoip(p+1);
 		else {
 			char *endp;
-			grad_uint32_t n = strtoul(p+1, &endp, 0);
+			uint32_t n = strtoul(p+1, &endp, 0);
 			if (*endp || n > 32)
 				return 1;
 			n = 32 - n;
@@ -219,7 +216,7 @@ grad_ip_getnetaddr(const char *str, grad_netdef_t *netdef)
 }
 
 int
-grad_ip_in_net_p(const grad_netdef_t *netdef, grad_uint32_t ipaddr)
+grad_ip_in_net_p(const grad_netdef_t *netdef, uint32_t ipaddr)
 {
 	return netdef->ipaddr == (ipaddr & netdef->netmask);
 }
