@@ -6,7 +6,7 @@
  * this stuff is worth it, you can buy me a beer in return.   Poul-Henning Kamp
  * ----------------------------------------------------------------------------
  *  
- * $Id: md5crypt.c,v 1.7 2005/05/18 12:22:02 gray Exp $
+ * $Id$
  *  
  */
 
@@ -18,9 +18,6 @@
 #include <stdio.h>
 #include <sysdep.h>
 #include <radius/md5.h>
-#if defined(HAVE_CRYPT_H)
-# include <crypt.h>
-#endif
 
 static unsigned char itoa64[] =         /* 0 ... 63 => ascii - 64 */
         "./0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
