@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2002,2003,2004,2006,2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2002-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -13,10 +13,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public
-   License along with GNU Radius; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA. */
+   You should have received a copy of the GNU General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -70,7 +68,7 @@ grad_pdu_init(struct radius_pdu *pdu)
    Return value: length of the data on *ptr. */
 static size_t
 grad_pdu_finish(void **ptr, struct radius_pdu *pdu,
-		int code, int id, u_char *authenticator, u_char *secret)
+		int code, int id, u_char *authenticator, char *secret)
 {
         grad_packet_header_t *hdr;
         void *p;
@@ -163,7 +161,7 @@ grad_attr_write(struct radius_attr *ap, void *data, size_t size)
 int
 grad_encode_pair(struct radius_attr *ap, grad_avp_t *pair)
 {
-        grad_uint32_t lval;
+        uint32_t lval;
         size_t len;
         int rc;
 
@@ -182,7 +180,7 @@ grad_encode_pair(struct radius_attr *ap, grad_avp_t *pair)
         case GRAD_TYPE_INTEGER:
         case GRAD_TYPE_IPADDR:
                 lval = htonl(pair->avp_lvalue);
-                rc = grad_attr_write(ap, &lval, sizeof(grad_uint32_t));
+                rc = grad_attr_write(ap, &lval, sizeof(uint32_t));
                 break;
 
         default:
@@ -201,7 +199,7 @@ grad_encode_pair(struct radius_attr *ap, grad_avp_t *pair)
    
 size_t
 grad_create_pdu(void **rptr, int code, int id, u_char *authenticator,
-		u_char *secret, grad_avp_t *pairlist, char *msg)
+		char *secret, grad_avp_t *pairlist, char *msg)
 {
         struct radius_pdu pdu;
         size_t attrlen = 0;
@@ -213,7 +211,7 @@ grad_create_pdu(void **rptr, int code, int id, u_char *authenticator,
 
         for (pair = pairlist; pair; pair = pair->next) {
                 struct radius_attr attr;
-                grad_uint32_t lval;
+                uint32_t lval;
                 int vendorcode, vendorpec;
                 
                 if (GRAD_DEBUG_LEVEL(10)) {
@@ -231,7 +229,7 @@ grad_create_pdu(void **rptr, int code, int id, u_char *authenticator,
                         grad_attr_write(&attr, &lval, 4);
 			if (vendorpec == 429) {
 				/* Hack for non-compliant USR VSA */
-				grad_uint32_t atval = htonl(pair->attribute & 0xffff);
+				uint32_t atval = htonl(pair->attribute & 0xffff);
 				grad_attr_write(&attr, &atval, 4);
 				attrlen = grad_encode_pair(&attr, pair);
 			} else {
@@ -295,11 +293,11 @@ grad_create_pdu(void **rptr, int code, int id, u_char *authenticator,
 }
 
 static grad_avp_t *
-grad_decode_pair(grad_uint32_t attrno, char *ptr, size_t attrlen)
+grad_decode_pair(uint32_t attrno, char *ptr, size_t attrlen)
 {
         grad_dict_attr_t *attr;
         grad_avp_t *pair;
-        grad_uint32_t lval;
+        uint32_t lval;
         
         if ((attr = grad_attr_number_to_dict(attrno)) == NULL) {
                 GRAD_DEBUG1(1, "Received unknown attribute %d", attrno);
@@ -325,9 +323,7 @@ grad_decode_pair(grad_uint32_t attrno, char *ptr, size_t attrlen)
         case GRAD_TYPE_STRING:
                 /* attrlen always <= GRAD_STRING_LENGTH */
                 pair->avp_strlength = attrlen;
-                pair->avp_strvalue = grad_emalloc(attrlen + 1);
-                memcpy(pair->avp_strvalue, ptr, attrlen);
-                pair->avp_strvalue[attrlen] = 0;
+                pair->avp_strvalue = grad_ebstrndup(ptr, attrlen);
 
                 if (GRAD_DEBUG_LEVEL(10)) {
                         char *save;
@@ -340,7 +336,7 @@ grad_decode_pair(grad_uint32_t attrno, char *ptr, size_t attrlen)
                         
         case GRAD_TYPE_INTEGER:
         case GRAD_TYPE_IPADDR:
-                memcpy(&lval, ptr, sizeof(grad_uint32_t));
+                memcpy(&lval, ptr, sizeof(uint32_t));
                 pair->avp_lvalue = ntohl(lval);
 
                 if (GRAD_DEBUG_LEVEL(10)) {
@@ -363,9 +359,9 @@ grad_decode_pair(grad_uint32_t attrno, char *ptr, size_t attrlen)
 }
 
 static int
-decode_vsa(u_char *ptr, grad_uint32_t attrlen, grad_uint32_t *vendorpec, grad_uint32_t *vendorcode)
+decode_vsa(u_char *ptr, uint32_t attrlen, uint32_t *vendorpec, uint32_t *vendorcode)
 {
-	grad_uint32_t x;
+	uint32_t x;
 	
 	if (attrlen < 6) { /*FIXME*/
 		grad_log(GRAD_LOG_NOTICE,
@@ -384,7 +380,7 @@ decode_vsa(u_char *ptr, grad_uint32_t attrlen, grad_uint32_t *vendorpec, grad_ui
    to the new structure. */
 
 grad_request_t *
-grad_decode_pdu(grad_uint32_t host, u_short udp_port, u_char *buffer, size_t length)
+grad_decode_pdu(uint32_t host, u_short udp_port, u_char *buffer, size_t length)
 {
         u_char          *ptr;
         grad_packet_header_t        *auth;
@@ -392,7 +388,7 @@ grad_decode_pdu(grad_uint32_t host, u_short udp_port, u_char *buffer, size_t len
         grad_avp_t      *prev;
         grad_avp_t      *pair;
         grad_request_t  *radreq;
-        grad_uint32_t reported_len;
+        uint32_t reported_len;
         u_char *endp;
         int stop;
         
@@ -431,7 +427,7 @@ grad_decode_pdu(grad_uint32_t host, u_short udp_port, u_char *buffer, size_t len
         stop = 0;
         
         while (ptr < endp && !stop) {
-                grad_uint32_t attrno, attrlen, vendorcode, vendorpec;
+                uint32_t attrno, attrlen, vendorcode, vendorpec;
                                 
                 attrno = *ptr++;
                 attrlen = *ptr++;
@@ -468,7 +464,7 @@ grad_decode_pdu(grad_uint32_t host, u_short udp_port, u_char *buffer, size_t len
 					attrlen -= len + 2;
 				}
 				
-                                pair = grad_decode_pair(attrno, ptr, len);
+                                pair = grad_decode_pair(attrno, (char*)ptr, len);
                                 if (pair) {
                                 	if (first_pair == NULL) 
                                         	first_pair = pair;
@@ -479,7 +475,7 @@ grad_decode_pdu(grad_uint32_t host, u_short udp_port, u_char *buffer, size_t len
                                 ptr += len;
                         }
                 } else {
-                        pair = grad_decode_pair(attrno, ptr, attrlen);
+                        pair = grad_decode_pair(attrno, (char*)ptr, attrlen);
                         ptr += attrlen;
                         if (pair) {
                         	if (first_pair == NULL) 
