@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2007 Free Software Foundation, Inc.
+   Copyright (C) 2007-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -13,14 +13,13 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public
-   License along with GNU Radius; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA. */
+   You should have received a copy of the GNU General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
+#include <ctype.h>
 #include <radlib.h>
 
 struct grad_slist_bucket {
@@ -38,7 +37,7 @@ struct grad_slist {
 static struct grad_slist_bucket *
 alloc_bucket(size_t size)
 {
-	struct grad_slist_bucket *p = grad_malloc(sizeof(*p) + size);
+	struct grad_slist_bucket *p = grad_emalloc(sizeof(*p) + size);
 	p->buf = (char*)(p + 1);
 	p->level = 0;
 	p->size = size;
@@ -74,9 +73,9 @@ copy_chars(grad_slist_t slist, char *str, size_t n)
 }
 
 grad_slist_t 
-grad_slist_create()
+grad_slist_create(void)
 {
-	grad_slist_t slist = grad_malloc(sizeof(*slist));
+	grad_slist_t slist = grad_emalloc(sizeof(*slist));
 	slist->head = slist->tail = 0;
 	return slist;
 }
@@ -100,11 +99,11 @@ grad_slist_free(grad_slist_t *slist)
 		grad_slist_clear(*slist);
 		for (p = (*slist)->free; p; ) {
 			struct grad_slist_bucket *next = p->next;
-			grad_free(p);
+			free(p);
 			p = next;
 		}
 	}
-	grad_free(*slist);
+	free(*slist);
 	*slist = NULL;
 }
 
@@ -143,15 +142,17 @@ grad_slist_coalesce(grad_slist_t slist)
 	if (slist->head && slist->head->next == NULL)
 		size = slist->head->level;
 	else {
-		size = grad_slist_size(slist);
-		struct grad_slist_bucket *bucket = alloc_bucket(size);
+		struct grad_slist_bucket *bucket;
 		struct grad_slist_bucket *p;
+
+		size = grad_slist_size(slist);
 	
+		bucket = alloc_bucket(size);
 		for (p = slist->head; p; ) {
 			struct grad_slist_bucket *next = p->next;
 			memcpy(bucket->buf + bucket->level, p->buf, p->level);
 			bucket->level += p->level;
-			grad_free(p);
+			free(p);
 			p = next;
 		}
 		slist->head = slist->tail = bucket;
@@ -162,7 +163,7 @@ grad_slist_coalesce(grad_slist_t slist)
 void *
 grad_slist_head(grad_slist_t slist, size_t *psize)
 {
-	if (*psize) 
+	if (psize) 
 		*psize = slist->head ? slist->head->level : 0;
 	return slist->head ? slist->head->buf : NULL;
 }
