@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2007,
-   2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -14,10 +13,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public
-   License along with GNU Radius; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA. */
+   You should have received a copy of the GNU General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #if defined(HAVE_CONFIG_H)
 # include <config.h>
@@ -72,7 +69,7 @@ grad_set_nonblocking(int fd)
  * Return maximum number of file descriptors available
  */
 int
-grad_max_fd()
+grad_max_fd(void)
 {
 #if defined(HAVE_GETDTABLESIZE)
         return getdtablesize();
@@ -87,10 +84,10 @@ grad_max_fd()
 #endif
 }
 
-static grad_uint32_t
-grad_first_ip_nameindex()
+static uint32_t
+grad_first_ip_nameindex(void)
 {
-	grad_uint32_t ip = INADDR_ANY;
+	uint32_t ip = INADDR_ANY;
 #ifdef SIOCGIFCONF
 	struct ifreq *ifr, *end, *cur;
 	struct ifconf ifc;
@@ -138,7 +135,7 @@ grad_first_ip_nameindex()
 
 		sinp = (struct sockaddr_in *)&cur->ifr_addr;
 		if (sinp->sin_family == AF_INET) {
-			grad_uint32_t n = ntohl(sinp->sin_addr.s_addr);
+			uint32_t n = ntohl(sinp->sin_addr.s_addr);
 
 			if (n != INADDR_LOOPBACK) {
 				ip = n;
@@ -153,10 +150,10 @@ grad_first_ip_nameindex()
 	return ip;
 }
 
-static grad_uint32_t
-grad_first_ip_hostname()
+static uint32_t
+grad_first_ip_hostname(void)
 {
-	grad_uint32_t ip = INADDR_ANY;
+	uint32_t ip = INADDR_ANY;
 	char *name;
 	int name_len = 256;
 	int status;
@@ -170,14 +167,14 @@ grad_first_ip_hostname()
 	}
 	if (status == 0) 
 		ip = grad_ip_gethostaddr(name);
-	grad_free(name);
+	free(name);
 	return ip;
 }
 
-grad_uint32_t
-grad_first_ip()
+uint32_t
+grad_first_ip(void)
 {
-	grad_uint32_t ip = INADDR_ANY;
+	uint32_t ip = INADDR_ANY;
 
 	ip = grad_first_ip_nameindex();
 	if (ip == INADDR_ANY)
