@@ -1,12 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public
-   License along with GNU Radius; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA. */
+   You should have received a copy of the GNU General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -40,12 +37,13 @@
 #include <sys/file.h>
 #include <pwd.h>
 #include <grp.h>
+#include <inttypes.h>
 
 #include <radlib.h>
 #include "intprops.h"
 
 grad_request_t *
-grad_request_alloc()
+grad_request_alloc(void)
 {
         return grad_emalloc(sizeof(grad_request_t));
 }
@@ -56,7 +54,7 @@ void
 grad_request_free(grad_request_t *radreq)
 {
         grad_avl_free(radreq->avlist);
-        grad_free(radreq);
+        free(radreq);
 }
 
 /* Turn printable string (dictionary type DATE) into correct tm struct entries
@@ -70,6 +68,8 @@ grad_parse_time_string(char *valstr, struct tm *tm)
 {
         int     i;
 
+	memset(tm, 0, sizeof *tm);
+	
         /* Get the month */
         for (i = 0; i < 12; i++) {
                 if (grad_c_strncasecmp(months[i], valstr, 3) == 0) {
@@ -102,6 +102,34 @@ grad_parse_time_string(char *valstr, struct tm *tm)
         return 0;
 }
 
+unsigned long
+grad_julianday(int year, int month, int day)
+{
+	int a = (14 - month) / 12;
+	int y = year + 4800 - a;
+	int m = month + 12*a - 3;
+
+	return day + (153*m + 2)/5 + 365*y + y/4 - y/100 + y/400 - 32045;
+}
+
+#define SECS_PER_DAY 86400
+#define JD_OF_EPOCH 2440588
+
+time_t
+grad_tm_to_epoch(struct tm *tm)
+{
+	unsigned long jd =
+		grad_julianday(tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday);
+	return (jd - JD_OF_EPOCH) * SECS_PER_DAY
+		+ (tm->tm_hour * 60 + tm->tm_min) * 60 + tm->tm_sec
+#ifdef HAVE_STRUCT_TM_TM_GMTOFF		
+		- tm->tm_gmtoff
+#endif
+		;
+}
+
+
+
 /* Lock `size' bytes on the file descriptor `fd' starting from `offset'.
  * `whence' determines from where the offset is counted (seek-like)
  */
@@ -214,7 +242,7 @@ grad_string_copy(char *d, char *s, int len)
         int slen = strlen(s);
         
         if (slen > len) 
-                grad_log(L_ERR, _("string too long: %s"), s);
+                grad_log(GRAD_LOG_ERR, _("string too long: %s"), s);
         strncpy(d, s, len);
         d[len] = 0;
 }
@@ -339,8 +367,8 @@ int
 grad_format_vendor_pair(char *buf, grad_avp_t *pair)
 {
         int n;
-        grad_uint32_t vendor;
-        u_char *ptr = (u_char*)pair->avp_strvalue;
+        uint32_t vendor;
+        char *ptr = pair->avp_strvalue;
         char buf1[64];
         char *bufp = buf;
         
@@ -383,12 +411,12 @@ grad_format_pair(grad_avp_t *pair, int typeflag, char **savep)
 						  pair->avp_strvalue, len);
                 } else if (pair->avp_strlength < 6) 
                         snprintf(buf2, sizeof(buf2),
-                                 "[invalid length: %d]", pair->avp_strlength);
+                                 "[invalid length: %zu]", pair->avp_strlength);
                 else {
                         int len = grad_format_vendor_pair(NULL, pair);
                         buf2ptr = malloc(len+1);
                         if (!buf2ptr) {
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
                                          "%s:%d: can't alloc %d bytes",
                                          __FILE__, __LINE__, len+1);
                                 buf2[0] = 0;
@@ -404,7 +432,7 @@ grad_format_pair(grad_avp_t *pair, int typeflag, char **savep)
                         dval = NULL;
                 
                 if (!dval)
-                        snprintf(buf2, sizeof(buf2), "%lu", pair->avp_lvalue);
+                        snprintf(buf2, sizeof(buf2), "%"PRIu32, pair->avp_lvalue);
                 else
                         snprintf(buf2, sizeof(buf2), "%s", dval->name);
                 break;
@@ -449,7 +477,7 @@ grad_format_pair(grad_avp_t *pair, int typeflag, char **savep)
 			     buf2ptr ? buf2ptr : buf2,
 			     NULL);
         else {
-		char buf[INT_STRLEN_BOUND (int)];
+		char buf[INT_BUFSIZE_BOUND (int)];
 
 		grad_inttostr(pair->attribute, buf, sizeof buf);
                 grad_astrcat(&buf1,
@@ -466,3 +494,21 @@ grad_format_pair(grad_avp_t *pair, int typeflag, char **savep)
         return buf1;
 }
 
+/* Recompute the timeout TVAL taking into account the time elapsed since
+   START */
+int
+grad_recompute_timeout(struct timeval *start, struct timeval *tval)
+{
+	struct timeval now, diff;
+	
+	gettimeofday(&now, NULL);
+	timersub(&now, start, &diff);
+	if (timercmp(&diff, tval, <)) {
+		struct timeval tmp;
+		timersub(tval, &diff, &tmp);
+		*tval = tmp;
+		return 0;
+	} 
+	return 1;
+}
+
