@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006,2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #define LOG_EMPTY_USERNAME
 
@@ -49,8 +47,7 @@
 int     doradwtmp = 1;
 
 static int write_wtmp(struct radutmp *ut);
-static int write_nas_restart(int status, grad_uint32_t addr);
-static int check_ts(struct radutmp *ut);
+static int write_nas_restart(int status, uint32_t addr);
 
 int rad_acct_system(radiusd_request_t *radreq, int dowtmp);
 int rad_acct_db(radiusd_request_t *radreq, int authtype);
@@ -59,18 +56,18 @@ int rad_acct_ext(radiusd_request_t *radreq);
 
 /* Zap a user, or all users on a NAS, from the radutmp file. */
 int
-radzap(grad_uint32_t nasaddr, int port, char *user, time_t t)
+radzap(uint32_t nasaddr, int port, char *user, time_t t)
 {
         struct radutmp  *up;
         radut_file_t    file;
-        grad_uint32_t           netaddr;
+        uint32_t           netaddr;
         
         if (t == 0) time(&t);
         netaddr = htonl(nasaddr);
 
-        if (file = grad_ut_setent(grad_utmp_file, 0)) {
+        if ((file = grad_ut_setent(grad_utmp_file, 0)) != NULL) {
                 /* Find the entry for this NAS / portno combination. */
-                while (up = grad_ut_getent(file)) {
+                while ((up = grad_ut_getent(file)) != NULL) {
                         if (((nasaddr != 0 && netaddr != up->nas_address) ||
                              (port >= 0   && port    != up->nas_port) ||
                              (user != NULL && strcmp(up->login, user) != 0) ||
@@ -377,7 +374,7 @@ rad_acct_system(radiusd_request_t *radreq, int dowtmp)
 }
 
 static void
-disable_system_acct()
+disable_system_acct(void)
 {
         radut_file_t file;
 	struct radutmp *up;
@@ -386,7 +383,7 @@ disable_system_acct()
         if ((file = grad_ut_setent(grad_utmp_file, 0)) == NULL)
                 return;
 
-        while (up = grad_ut_getent(file)) {
+        while ((up = grad_ut_getent(file)) != NULL) {
                 switch (up->type) {
 		case P_LOGIN:
                         up->type = P_IDLE;
@@ -423,15 +420,15 @@ disable_system_acct()
 }
 
 static void
-enable_system_acct()
+enable_system_acct(void)
 {
         radut_file_t file;
-	struct radutmp *up, ut;
+	struct radutmp *up;
 		
         if ((file = grad_ut_setent(grad_utmp_file, 0)) == NULL)
                 return;
 
-        while (up = grad_ut_getent(file)) {
+        while ((up = grad_ut_getent(file)) != NULL) {
                 if (up->type == P_ACCT_DISABLED) {
                         up->type = P_ACCT_ENABLED;
                         time(&up->time);
@@ -444,7 +441,7 @@ enable_system_acct()
 }
 
 void
-system_acct_init()
+system_acct_init(void)
 {
 	if (acct_system)
 		enable_system_acct();
@@ -493,7 +490,7 @@ mkdir_path(char *path, int perms)
 }
 
 static int
-check_acct_dir()
+check_acct_dir(void)
 {
         struct stat st;
 
@@ -534,7 +531,7 @@ acct_after_config_hook(void *arg ARG_UNUSED, void *data ARG_UNUSED)
 }
 
 void
-acct_init()
+acct_init(void)
 {
 	radiusd_set_postconfig_hook(acct_after_config_hook, NULL, 0);
 }
@@ -544,7 +541,7 @@ make_legacy_detail_filename(radiusd_request_t *radreq, char *default_filename)
 {
 	char nasname[GRAD_MAX_LONGNAME];
 	grad_nas_t *cl;
-	grad_uint32_t ip;
+	uint32_t ip;
 	grad_avp_t *pair;
 	
         /* Find out the name of this terminal server. We try to find
@@ -661,7 +658,7 @@ write_detail(radiusd_request_t *radreq, int authtype, int rtype)
 
 	/* Change to the accounting directory */
 	if (chdir(grad_acct_dir)) {
-		grad_free(filename);
+		free(filename);
 		return 1;
 	}
 	
@@ -737,7 +734,7 @@ write_detail(radiusd_request_t *radreq, int authtype, int rtype)
                 ret = 0;
         }
 	
-        grad_free(filename);
+        free(filename);
         chdir("/");
         return ret;
 }
@@ -816,7 +813,7 @@ rad_accounting(radiusd_request_t *radreq, int activefd, int verified)
 }
 
 int
-write_nas_restart(int status, grad_uint32_t addr)
+write_nas_restart(int status, uint32_t addr)
 {
         struct radutmp ut;
 
@@ -843,7 +840,7 @@ radutmp_mlc_collect_user(char *name, radiusd_request_t *request,
         if ((file = grad_ut_setent(grad_utmp_file, 0)) == NULL)
                 return 1;
 
-        while (up = grad_ut_getent(file)) {
+        while ((up = grad_ut_getent(file)) != NULL) {
                 if (strncmp(name, up->login, RUT_NAMESIZE) == 0 &&
                     up->type == P_LOGIN) {
 			struct radutmp *tmp;
@@ -868,7 +865,7 @@ radutmp_mlc_collect_realm(radiusd_request_t *request, grad_list_t **sess_list)
         if ((file = grad_ut_setent(grad_utmp_file, 0)) == NULL)
                 return 1;
 
-        while (up = grad_ut_getent(file)) {
+        while ((up = grad_ut_getent(file)) != NULL) {
                 if (up->type == P_LOGIN
 		    && grad_realm_verify_ip(request->realm, up->realm_address)) {
 			struct radutmp *tmp;
@@ -893,7 +890,7 @@ radutmp_mlc_close(struct radutmp *up)
 }
 
 int
-radutmp_mlc_enabled_p()
+radutmp_mlc_enabled_p(void)
 {
 	return acct_system;
 }
