@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius
-   Copyright (C) 2000,2001,2002,2003,2004,
-   2006,2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -35,10 +33,6 @@
 #include <errno.h>
 #include <sys/wait.h>
 
-#if defined(HAVE_CRYPT_H)
-# include <crypt.h>
-#endif
-
 #if defined(PWD_SHADOW)
 # if PWD_SHADOW == SHADOW
 #  include <shadow.h>
@@ -65,6 +59,7 @@
 #endif
 
 #include <radiusd.h>
+#include <radius/md5.h>
 #include <timestr.h>
 #include <rewrite.h>
 
@@ -217,12 +212,12 @@ unix_pass(char *name, char *passwd)
 	STRUCT_SHADOW_PASSWD *spwd;
 
 	LOCK_SET(lock);
-	if (spwd = GETSPNAM(name))
+	if ((spwd = GETSPNAM(name)) != NULL)
                 encrypted_pass = SHADOW_PASSWD_ENCRYPTED(spwd);
 	else { /* Try to get encrypted password from password file */
 		struct passwd *pwd;
 
-		if (pwd = getpwnam(name)) 
+		if ((pwd = getpwnam(name)) != NULL)
 			encrypted_pass = pwd->pw_passwd;
 	}
 
@@ -266,8 +261,8 @@ unix_pass(char *name, char *passwd)
         rc = grad_md5crypt(passwd, encrypted_pass, encpw, pwlen+1) == NULL
                 || strlen (encpw) != pwlen
 		|| memcmp(encpw, encrypted_pass, pwlen);
-        grad_free(encpw);
-	grad_free(encrypted_pass);
+        free(encpw);
+	free(encrypted_pass);
         if (rc)
                 return -1;
 
@@ -388,8 +383,6 @@ static void sfn_ack(AUTH_MACH*);
 static void sfn_exec_nowait(AUTH_MACH*);
 static void sfn_reject(AUTH_MACH*);
 static void sfn_reject_cleanup(AUTH_MACH *m);
-static int check_expiration(AUTH_MACH *m);
-
 
 struct auth_state_s {
         enum auth_state this;
@@ -525,10 +518,10 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
         int length;
         enum auth_status result = auth_ok;
         char *authdata = NULL;
-        char pw_digest[GRAD_AUTHENTICATOR_LENGTH];
+        u_char pw_digest[GRAD_AUTHENTICATOR_LENGTH];
         int pwlen;
         char *pwbuf;
-        char *challenge;
+        u_char *challenge;
 	int challenge_len;
 	
         m->userpass[0] = 0;
@@ -550,8 +543,9 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
 
         /* Find the password sent by the user. If it's not present,
            authentication fails. */
-        
-        if (auth_item = grad_avl_find(radreq->request->avlist, DA_CHAP_PASSWORD))
+
+	auth_item = grad_avl_find(radreq->request->avlist, DA_CHAP_PASSWORD);
+        if (auth_item)
                 auth_type = DV_AUTH_TYPE_LOCAL;
         else
                 auth_item = grad_avl_find(radreq->request->avlist, DA_USER_PASSWORD);
@@ -574,7 +568,8 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
         tmp = grad_avl_find(m->user_check, DA_USER_PASSWORD);
         if (tmp)
                 real_password = grad_estrdup(tmp->avp_strvalue);
-        else if (tmp = grad_avl_find(m->user_check, DA_PASSWORD_LOCATION)) {
+        else if ((tmp = grad_avl_find(m->user_check, DA_PASSWORD_LOCATION))
+		 != NULL) {
                 switch (tmp->avp_lvalue) {
                 case DV_PASSWORD_LOCATION_SQL:
 #ifdef USE_SQL
@@ -641,7 +636,7 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
                 else if (strcmp(real_password, pwbuf) != 0)
                         result = auth_fail;
                 GRAD_DEBUG1(1, "pwbuf: %s", pwbuf);
-                grad_free(pwbuf);
+                free(pwbuf);
                 break;
                 
         case DV_AUTH_TYPE_LOCAL:
@@ -675,10 +670,11 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
 		/* Compute the length of the password buffer and
 		   allocate it */
                 length = strlen(real_password);
-		
-                if (tmp = grad_avl_find(radreq->request->avlist,
-					DA_CHAP_CHALLENGE)) {
-                        challenge = tmp->avp_strvalue;
+
+		tmp = grad_avl_find(radreq->request->avlist,
+				    DA_CHAP_CHALLENGE);
+                if (tmp) {
+                        challenge = (u_char*) tmp->avp_strvalue;
                         challenge_len = tmp->avp_strlength;
                 } else {
                         challenge = radreq->request->authenticator;
@@ -696,7 +692,7 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
 
 		/* Compute the MD5 hash */
                 grad_md5_calc(pw_digest, (u_char*) pwbuf, pwlen);
-                grad_free(pwbuf);
+                free(pwbuf);
 		
                 /* Compare them */
                 if (memcmp(pw_digest, auth_item->avp_strvalue + 1,
@@ -717,7 +713,7 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
         if (real_password) {
                 /* just in case: */
                 memset(real_password, 0, strlen(real_password)); 
-                grad_free(real_password);
+                free(real_password);
         }
         return result;
 }
@@ -728,7 +724,7 @@ radius_check_expiration(AUTH_MACH *m, time_t *exp)
 {
         grad_avp_t *pair;
         
-        if (pair = grad_avl_find(m->user_check, DA_EXPIRATION)) {
+        if ((pair = grad_avl_find(m->user_check, DA_EXPIRATION)) != NULL) {
 		struct timeval tv;
 		gettimeofday(&tv, NULL);
 		if (tv.tv_sec > pair->avp_lvalue)
@@ -780,7 +776,7 @@ rad_authenticate(radiusd_request_t *radreq, int activefd)
                         default:
                                 abort();
                         }
-                        if (p = grad_avl_find(p, sp->attr))
+                        if ((p = grad_avl_find(p, sp->attr)) != NULL)
                                 m.check_pair = p;
                         else {
                                 m.state = sp->next;
@@ -1061,7 +1057,7 @@ sfn_simuse(AUTH_MACH *m)
 {
         char  name[GRAD_STRING_LENGTH];
         int rc;
-        int count;
+        size_t count;
 	
         strip_username(strip_names,
                        m->namepair->avp_strvalue, m->user_check, name);
@@ -1084,8 +1080,8 @@ sfn_simuse(AUTH_MACH *m)
         newstate(as_reject_cleanup);
 }
 
-static grad_uint32_t
-set_session_timeout(AUTH_MACH *m, grad_uint32_t val)
+static uint32_t
+set_session_timeout(AUTH_MACH *m, uint32_t val)
 {
 	grad_avp_t *p;
 	
@@ -1120,7 +1116,7 @@ sfn_time(AUTH_MACH *m)
                 /*
                  * User is allowed, but set Session-Timeout.
                  */
-                grad_uint32_t to = set_session_timeout(m, rest);
+                uint32_t to = set_session_timeout(m, rest);
                 GRAD_DEBUG4(2, "user %s, span %s, timeout %d, real timeout %d",
                             m->namepair->avp_strvalue,
                             m->check_pair->avp_strvalue,
@@ -1132,12 +1128,12 @@ sfn_time(AUTH_MACH *m)
 void
 sfn_ipaddr(AUTH_MACH *m)
 {
-        grad_avp_t *p, *tmp, *pp;
+        grad_avp_t *p;
         
         /* Assign an IP if necessary */
         if (!grad_avl_find(m->user_reply, DA_FRAMED_IP_ADDRESS)) {
-                if (p = grad_avl_find(m->req->request->avlist,
-				      DA_FRAMED_IP_ADDRESS)) {
+                if ((p = grad_avl_find(m->req->request->avlist,
+				       DA_FRAMED_IP_ADDRESS)) != NULL) {
                         /* termserver hint */
                         grad_avl_add_pair(&m->user_reply, grad_avp_dup(p));
                 }
@@ -1219,7 +1215,7 @@ sfn_menu_challenge(AUTH_MACH *m)
         snprintf(state_value, sizeof(state_value),
                    "MENU=%s", m->check_pair->avp_strvalue);
         radius_send_challenge(m->req, msg, state_value, m->activefd);
-        grad_free(msg);
+        free(msg);
 	
         GRAD_DEBUG2(1, "sending challenge (menu %s) to %s",
                     m->check_pair->avp_strvalue, m->namepair->avp_strvalue);
