@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius
-   Copyright (C) 2001,2003,2004,2005,2006,2007 Free Software Foundation, Inc.
+   Copyright (C) 2001-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
  
    GNU Radius is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -56,7 +55,7 @@ append_symbol(DBM_closure *closure, User_symbol *sym)
         reply_len = list_length(sym->reply);
 
         if (2 + check_len + reply_len > closure->pair_buffer_size) {
-                grad_log(L_ERR, "%s:%d: %s",
+                grad_log(GRAD_LOG_ERR, "%s:%d: %s",
                          closure->filename, sym->lineno,
 		         _("too many attributes"));
                 return -1;
@@ -98,7 +97,7 @@ append_symbol(DBM_closure *closure, User_symbol *sym)
         contentd.dptr = (char*)closure->pair_buffer;
         contentd.dsize = (2 + check_len + reply_len) * sizeof(int);
         if (grad_dbm_insert(closure->dbmfile, named, contentd)) {
-                grad_log(L_ERR, _("can't store datum for %s"), name);
+                grad_log(GRAD_LOG_ERR, _("can't store datum for %s"), name);
                 exit(1);
         }
         return 0;
@@ -135,10 +134,12 @@ builddbm(char *name)
          */
         closure.filename = db_file;
         closure.pair_buffer_size = RAD_BUFFER_SIZE;
-        closure.pair_buffer = grad_emalloc(closure.pair_buffer_size*sizeof(int));
+        closure.pair_buffer = grad_ecalloc(closure.pair_buffer_size,
+					   sizeof(int));
         closure.defno = closure.begno = 0;
         if (grad_dbm_create(db_file, &closure.dbmfile)) {
-                grad_log(L_ERR|L_PERROR, _("can't open `%s'"), db_file);
+                grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR, 
+                         _("can't open `%s'"), db_file);
                 return 1;
         }
 
@@ -257,7 +258,7 @@ dbm_find(DBM_FILE file, char *name, radiusd_request_t *req,
                                        req,
                                        &check_tmp, &reply_tmp, &dummy))
                                 ret = 0;
-                        grad_free(name);
+                        free(name);
                 } 
                 
                 if (ret == 1) {
@@ -328,7 +329,7 @@ dbm_match(DBM_FILE dbmfile, char *name, char *(*fn)(), radiusd_request_t *req,
                         dbm_match(dbmfile, name, _dbm_dup_name,
                                   req,
                                   check_pairs, reply_pairs, &dummy);
-                        grad_free(name);
+                        free(name);
                 }
 
                 if (!fallthrough(*reply_pairs))
@@ -353,8 +354,8 @@ user_find_db(char *name, radiusd_request_t *req,
         
         path = grad_mkfilename(grad_config_dir, RADIUS_USERS);
         if (grad_dbm_open(path, &dbmfile)) {
-                grad_log(L_ERR, _("cannot open dbm file %s"), path);
-                grad_free(path);
+                grad_log(GRAD_LOG_ERR, _("cannot open dbm file %s"), path);
+                free(path);
                 return 0;
         }
 
@@ -383,7 +384,7 @@ user_find_db(char *name, radiusd_request_t *req,
         }
 
         grad_dbm_close(dbmfile);
-        grad_free(path);
+        free(path);
 
         GRAD_DEBUG1(1, "returning %d", found);
 
