@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006,2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #if defined(HAVE_CONFIG_H)
 # include <config.h>
@@ -51,10 +49,10 @@
 struct check_instance {
 	/* Data from the radutmp entry */
         char          *name;       /* User name */
-	grad_uint32_t nas_ip;      /* NAS IP address */
+	uint32_t nas_ip;      /* NAS IP address */
         int           port;        /* NAS port number */
         char          *sid;        /* Session ID */
-        grad_uint32_t framed_ip;   /* Framed IP address */
+        uint32_t framed_ip;   /* Framed IP address */
 
 	/* Data from the nastypes entry */
 	int           method;      /* Method to be used */
@@ -101,7 +99,7 @@ create_instance(struct check_instance *cptr, grad_nas_t *nas, struct radutmp *up
 	cptr->nas_ip = ntohl(up->nas_address);
 	cptr->result = -1;
         cptr->timeout = 0;
-        cptr->nasname = nas->shortname ? nas->shortname : nas->longname;
+        cptr->nasname = nas->shortname[0] ? nas->shortname : nas->longname;
         
         cptr->method = radck_type->method;
         cptr->args = grad_envar_merge_lists((grad_envar_t*) nas->args,
@@ -255,7 +253,7 @@ converse(int type, struct snmp_session *sp, struct snmp_pdu *pdu, void *closure)
         for (vlist = pdu->var; rc == 0 && vlist; vlist = vlist->next)  
                 switch (vlist->type) {
                 case SMI_STRING:
-                        rc = compare(checkp, vlist->var_str);
+                        rc = compare(checkp, (char*)vlist->var_str);
                         GRAD_DEBUG2(2, "(STRING) %s: %d", vlist->var_str, rc);
                         break;
                 case SMI_INTEGER:
@@ -266,10 +264,10 @@ converse(int type, struct snmp_session *sp, struct snmp_pdu *pdu, void *closure)
                         GRAD_DEBUG2(2, "(INT) %d: %d", vlist->var_int, rc);
                         break;
                 case SMI_IPADDRESS:
-                        grad_ip_iptostr(*(grad_uint32_t*)vlist->var_int, buf);
+                        grad_ip_iptostr(*(uint32_t*) vlist->var_str, buf);
                         rc = compare(checkp, buf);
                         GRAD_DEBUG2(2, "(IPADDR) %#x: %d",
-                                    *(grad_uint32_t*)vlist->var_str, rc);
+                                    *(uint32_t*)vlist->var_str, rc);
                         break;
                 }
 
@@ -376,8 +374,8 @@ snmp_check(struct check_instance *checkp, grad_nas_t *nas)
 
 static jmp_buf to_env;
 
-static RETSIGTYPE
-alrm_handler()
+static void
+alrm_handler(int sig)
 {
 	longjmp(to_env, 1);
 }
@@ -401,7 +399,7 @@ finger_check(struct check_instance *checkp, grad_nas_t *nas)
         int found = 0;
         char *peername;
         char *ptr;
-        RETSIGTYPE (*handler)() = SIG_IGN;
+        void (*handler)(int) = SIG_IGN;
         unsigned int to;
 	
         arg = checkrad_xlat(checkp, slookup(checkp, "arg", "%u"));
@@ -424,7 +422,7 @@ finger_check(struct check_instance *checkp, grad_nas_t *nas)
         if ((port = ilookup(checkp, "port", 0)) == 0) {
                 struct servent *sp;
                 
-                if (sp = getservbyname("finger", "tcp")) 
+                if ((sp = getservbyname("finger", "tcp")) != NULL)
                         port = sp->s_port;
                 else
                         port = htons(79);
