@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2002,2003,2004,2005,2006,2007,
-   2008 Free Software Foundation, Inc.
+   Copyright (C) 2002-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -165,10 +163,9 @@ int
 radius_exec_command(char *cmd)
 {
         int n;
-        grad_avp_t *vp;
 	pid_t pid;
 	int status;
-	RETSIGTYPE (*oldsig)();
+	void (*oldsig)(int);
 	
         if (cmd[0] != '/') {
                 grad_log(GRAD_LOG_ERR,
@@ -259,7 +256,7 @@ radius_exec_program(char *cmd, radiusd_request_t *req, grad_avp_t **reply,
         char buffer[RAD_BUFFER_SIZE];
 	pid_t pid;
 	int status;
-	RETSIGTYPE (*oldsig)();
+	void (*oldsig)(int);
 	
         if (cmd[0] != '/') {
                 grad_log(GRAD_LOG_ERR,
@@ -332,7 +329,7 @@ radius_exec_program(char *cmd, radiusd_request_t *req, grad_avp_t **reply,
         vp = NULL;
         line_num = 0;
 
-        while (ptr = fgets(buffer, sizeof(buffer), fp)) {
+        while ((ptr = fgets(buffer, sizeof(buffer), fp)) != NULL) {
                 line_num++;
                 GRAD_DEBUG1(1, "got `%s'", buffer);
                 if (userparse(ptr, &vp, &errp)) {
@@ -776,16 +773,16 @@ filter_acct(char *name, radiusd_request_t *req)
 
 static struct filter_symbol filter_symbol;
 
-static int
-free_symbol_entry(Filter *filter)
+static void
+free_symbol_entry(void *p)
 {
-	grad_free(filter->descr[R_AUTH].input_fmt);
-	grad_free(filter->descr[R_ACCT].input_fmt);
+	Filter *filter = p;
+	free(filter->descr[R_AUTH].input_fmt);
+	free(filter->descr[R_ACCT].input_fmt);
 	grad_argcv_free(filter->argc, filter->argv);
-	grad_free(filter->errfile);
+	free(filter->errfile);
 	if (filter->pid > 0)
 		filter_close(filter);
-	return 0;
 }
 
 int
@@ -904,7 +901,7 @@ error_log_handler(int argc, cfg_value_t *argv,
 		char *p = grad_mkfilename(grad_log_dir, argv[1].v.string);
 		filter_symbol.errfile = cfg_malloc(strlen(p)+1, NULL);
 		strcpy(filter_symbol.errfile, p);
-		grad_free(p);
+		free(p);
 	}
 	return 0;
 }
