@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006,2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 /* This file deals with contents of /etc/raddb directory (except config and
    dictionaries) */
@@ -106,7 +104,6 @@ int fallthrough(grad_avp_t *vp);
 static int portcmp(grad_avp_t *check, grad_avp_t *request);
 static int groupcmp(radiusd_request_t *req, char *groupname, char *username);
 static int uidcmp(grad_avp_t *check, char *username);
-static void matchrule_free(grad_matching_rule_t **pl);
 static int matches(radiusd_request_t *req, char *name, grad_matching_rule_t *pl, char *matchpart);
 static int huntgroup_match(radiusd_request_t *req, char *huntgroup);
 static int user_find_sym(char *name, radiusd_request_t *req, 
@@ -196,13 +193,13 @@ add_user_entry(void *closure, grad_locus_t *loc,
         return 0;
 }
 
-static int
-free_user_entry(User_symbol *sym)
+static void
+free_user_entry(void *p)
 {
+	User_symbol *sym = p;
 	locus_free(&sym->loc);
         grad_avl_free(sym->check);
         grad_avl_free(sym->reply);
-        return 0;
 }
 
 struct temp_data {
@@ -239,7 +236,8 @@ int
 read_users(char *name)
 {
         if (!user_tab)
-                user_tab = grad_symtab_create(sizeof(User_symbol), free_user_entry);
+                user_tab = grad_symtab_create(sizeof(User_symbol),
+					      free_user_entry);
         return grad_parse_rule_file(name, user_tab, add_user_entry);
 }
 
@@ -396,7 +394,7 @@ match_user(User_symbol *sym, radiusd_request_t *req,
                         break;
                 GRAD_DEBUG2(1, "fall through near %s:%lu",
 			    sym->loc.file, (unsigned long) sym->loc.line);
-        } while (sym = grad_sym_next((grad_symbol_t*)sym));
+        } while ((sym = grad_sym_next((grad_symbol_t*)sym)) != NULL);
 
         return found;
 }
@@ -881,7 +879,6 @@ huntgroup_match(radiusd_request_t *req, char *huntgroup)
 int
 huntgroup_access(radiusd_request_t *radreq, grad_locus_t *loc)
 {
-        grad_avp_t      *pair;
         grad_matching_rule_t   *rule;
 	grad_iterator_t *itr;
         int             r = 1;
@@ -958,8 +955,8 @@ static int
 client_free(void *item, void *data ARG_UNUSED)
 {
         CLIENT *cl = item;
-        grad_free(cl->secret);
-        grad_free(cl);
+        free(cl->secret);
+        free(cl);
         return 0;
 }
 
@@ -979,7 +976,7 @@ read_clients_file(char *file)
  * Find a client in the CLIENTS list.
  */
 CLIENT *
-client_lookup_ip(grad_uint32_t ipaddr)
+client_lookup_ip(uint32_t ipaddr)
 {
         CLIENT *cl;
         grad_iterator_t *itr = grad_iterator_create(clients);
@@ -1009,7 +1006,7 @@ client_lookup_ip(grad_uint32_t ipaddr)
  * Find the name of a client (prefer short name).
  */
 char *
-client_lookup_name(grad_uint32_t ipaddr, char *buf, size_t bufsize)
+client_lookup_name(uint32_t ipaddr, char *buf, size_t bufsize)
 {
         CLIENT *cl;
 
@@ -1081,9 +1078,9 @@ free_radck_type(void *item, void *data ARG_UNUSED)
 {
         RADCK_TYPE *rp = item;
 
-        grad_free(rp->type);
+        free(rp->type);
         grad_envar_free_list(&rp->args);
-	grad_free(rp);
+	free(rp);
 	return 0;
 }
 
@@ -1146,7 +1143,7 @@ read_denylist_entry(void *closure, int fc, char **fv, grad_locus_t *loc)
 }
 
 void
-read_deny_file()
+read_deny_file(void)
 {
         int denycnt;
         char *name;
@@ -1159,7 +1156,7 @@ read_deny_file()
         denycnt = 0;
 
         grad_read_raddb_file(name, 0, NULL, read_denylist_entry, &denycnt);
-        grad_free(name);
+        free(name);
         if (denycnt)
                 grad_log(GRAD_LOG_INFO,
 		         ngettext ("%d user disabled",
@@ -1254,7 +1251,7 @@ system_groupcmp(radiusd_request_t *req, char *groupname, char *username)
 		if (strcmp(*member, pwd->pw_name) == 0)
 			retval = 0;
 	}
-	grad_free(grp);
+	free(grp);
 	
 	return retval;
 }
@@ -1263,8 +1260,6 @@ system_groupcmp(radiusd_request_t *req, char *groupname, char *username)
 int
 groupcmp(radiusd_request_t *req, char *groupname, char *username)
 {
-        int retval;
-
 	return system_groupcmp(req, groupname, username)
 		&& radiusd_sql_checkgroup(req, groupname);
 }
@@ -1499,12 +1494,13 @@ matching_rule_free(void *item, void *data ARG_UNUSED)
 	grad_matching_rule_t *p = item;
 	
 	if (p->name)
-		grad_free(p->name);
+		free(p->name);
 	if (p->lhs)
 		grad_avl_free(p->lhs);
 	if (p->rhs)
 		grad_avl_free(p->rhs);
-	grad_free(p);
+	free(p);
+	return 0;
 }
 
 /* ***************************************************************************
@@ -1550,7 +1546,7 @@ match_char_class(char **pexpr, char c)
 				expr += 2;
 			}
 		} else if (*expr == '\\' && expr[1] == ']')
-			rc == *++expr == c;
+			rc = *++expr == c;
 		else
 			rc = *expr == c;
 	}
@@ -1673,7 +1669,7 @@ checkdbm(char *users, char *ext)
         buffer = grad_emalloc(strlen(users) + strlen(ext) + 1);
         strcat(strcpy(buffer, users), ext);
         rc = stat(buffer, &st);
-        grad_free(buffer);
+        free(buffer);
         return rc;
 }
 #endif
@@ -1737,7 +1733,7 @@ reload_data(enum reload_what what, int *do_radck)
 #if USE_DBM
                 }
 #endif
-                grad_free(path);
+                free(path);
                 break;
 
         case reload_dict:
@@ -1756,14 +1752,14 @@ reload_data(enum reload_what what, int *do_radck)
                 grad_list_destroy(&huntgroups, matching_rule_free, NULL);
                 path = grad_mkfilename(grad_config_dir, RADIUS_HUNTGROUPS);
                 huntgroups = file_read(GRAD_CF_HUNTGROUPS, path);
-                grad_free(path);
+                free(path);
                 break;
                 
         case reload_hints:
                 grad_list_destroy(&hints, matching_rule_free, NULL);
                 path = grad_mkfilename(grad_config_dir, RADIUS_HINTS);
                 hints = file_read(GRAD_CF_HINTS, path);
-                grad_free(path);
+                free(path);
                 if (!use_dbm) 
                         *do_radck = 1;
                 break;
@@ -1772,20 +1768,20 @@ reload_data(enum reload_what what, int *do_radck)
                 path = grad_mkfilename(grad_config_dir, RADIUS_CLIENTS);
                 if (read_clients_file(path) < 0)
                         rc = 1;
-                grad_free(path);
+                free(path);
                 break;
 
         case reload_naslist:
                 /*FIXME*/
 		path = grad_mkfilename(grad_config_dir, RADIUS_NASTYPES);
                 read_nastypes_file(path);
-                grad_free(path);
+                free(path);
                 /*EMXIF*/
 
                 path = grad_mkfilename(grad_config_dir, RADIUS_NASLIST);
                 if (read_naslist_file(path) < 0)
                         rc = 1;
-                grad_free(path);
+                free(path);
                 break;
 
         case reload_realms:
@@ -1793,7 +1789,7 @@ reload_data(enum reload_what what, int *do_radck)
                 if (grad_read_realms(path, auth_port, acct_port,
 				     realm_set_secret) < 0)
                         rc = 1;
-                grad_free(path);
+                free(path);
                 break;
                 
         case reload_deny:
@@ -1882,7 +1878,7 @@ dump_user(void *data, grad_symbol_t *symbol)
 }
 
 void
-dump_users_db()
+dump_users_db(void)
 {
         FILE *fp;
         char *name = grad_mkfilename(grad_log_dir, RADIUS_DUMPDB_NAME);
@@ -1892,7 +1888,7 @@ dump_users_db()
                 grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR,
                          _("can't create parser output file `%s'"),
                          RADIUS_DUMPDB_NAME);
-                grad_free(name);
+                free(name);
                 return;
         }
 
@@ -1906,7 +1902,7 @@ dump_users_db()
         dump_matching_rules(fp, "hints", hints);
         grad_log(GRAD_LOG_INFO, _("dumped users database to %s"), RADIUS_DUMPDB_NAME);
         fclose(fp);
-        grad_free(name);
+        free(name);
 }
 
 /* ***************************************************************************
@@ -1927,7 +1923,8 @@ strip_username(int do_strip, char *name, grad_avp_t *check_item,
         if ((presuf_item = grad_avl_find(check_item, DA_PREFIX)) == NULL)
                 presuf_item = grad_avl_find(check_item, DA_SUFFIX);
         if (presuf_item) {
-                if (tmp = grad_avl_find(check_item, DA_STRIP_USER_NAME))
+		tmp = grad_avl_find(check_item, DA_STRIP_USER_NAME);
+                if (tmp)
                         do_strip = tmp->avp_lvalue;
                 if (do_strip) { 
                         if (presufcmp(presuf_item, name, tmpname) == 0)
