@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2003,2004,2006,2007 Free Software Foundation, Inc.
+   Copyright (C) 2003-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -50,7 +49,7 @@ struct input_channel {
 };
 
 INPUT *
-input_create()
+input_create(void)
 {
 	INPUT *p = grad_emalloc(sizeof(*p));
 	p->methods = grad_list_create();
@@ -127,7 +126,7 @@ channel_close(INPUT *input, CHANNEL *chan)
 		chan->method->close(chan->fd, chan->data);
 	FD_CLR(chan->fd, &input->fdset);
 	input->fd_max = -2;
-	grad_free(chan);
+	free(chan);
 }
 
 static int
