@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2006,
-   2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 /* Multiple Login Checking */
 
@@ -59,7 +57,7 @@ mlc_register_method(char *name,
 
 /* Entry points */
 int
-radius_mlc_enabled_p()
+radius_mlc_enabled_p(void)
 {
 	return mlc_disptab ? mlc_disptab->enabled_p() : 0;
 }
@@ -145,7 +143,7 @@ rad_check_ts(struct radutmp *ut)
 static int
 utmp_free(void *item, void *data ARG_UNUSED)
 {
-	grad_free(item);
+	free(item);
 	return 0;
 }
 
@@ -163,7 +161,6 @@ int
 radius_mlc_user(char *name, radiusd_request_t *request,
 		size_t maxsimul, size_t *pcount)
 {
-	void *mlc;
         struct radutmp *up;
         int mpp = 1; /* MPP flag. The sense is reversed: 1 if
                         the session is NOT an MPP one */
@@ -182,7 +179,7 @@ radius_mlc_user(char *name, radiusd_request_t *request,
 	      
         if (count >= maxsimul) {
 		grad_iterator_t *itr;
-		grad_uint32_t ipno = 0;
+		uint32_t ipno = 0;
 		grad_avp_t *fra = grad_avl_find(request->request->avlist,
 						DA_FRAMED_IP_ADDRESS);
 		if (fra)
@@ -224,7 +221,6 @@ radius_mlc_realm(radiusd_request_t *request)
 {
         size_t count;
         struct radutmp *up;
-        radut_file_t file;
         size_t maxlogins;
 	grad_list_t *sess_list = NULL;
 	grad_realm_t *realm = request->realm;
@@ -301,7 +297,7 @@ struct cfg_stmt mlc_stmt[] = {
 
 
 void
-mlc_init()
+mlc_init(void)
 {
 	mlc_register_method("system",
 			    radutmp_mlc_collect_user,
