@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2006,
-   2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -15,14 +14,14 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
 #include <radiusd.h>
+#include <radius/md5.h>
 
 /* Build and send a reply to the incoming request.
    Input: code        -- Reply code.
@@ -104,7 +103,7 @@ validate_client(grad_request_t *radreq)
         CLIENT  *cl;
         
         if ((cl = client_lookup_ip(radreq->ipaddr)) == NULL) {
-                grad_log_req(L_ERR, radreq,
+                grad_log_req(GRAD_LOG_ERR, radreq,
 			     _("request from unknown client"));
                 return -1;
         }
@@ -145,7 +144,7 @@ radius_verify_digest(REQUEST *req)
         memset(recvbuf + 4, 0, GRAD_AUTHENTICATOR_LENGTH);
         memcpy(recvbuf + len, radreq->request->secret, secretlen);
         grad_md5_calc(digest, recvbuf, len + secretlen);
-        grad_free(recvbuf);
+        free(recvbuf);
         
         return memcmp(digest, radreq->request->authenticator,
 		      GRAD_AUTHENTICATOR_LENGTH) ?
@@ -174,7 +173,7 @@ radius_auth_req_decode(const struct sockaddr_in *srv_sa,
 	grad_request_t *greq;
         radiusd_request_t *radreq;
 
-	log_open(L_AUTH);
+	log_open(GRAD_LOG_AUTH);
 
         if (suspend_flag) {
 		stat_inc(auth, ntohl(clt_sa->sin_addr.s_addr), num_dropped);
@@ -223,7 +222,7 @@ radius_acct_req_decode(const struct sockaddr_in *srv_sa,
 {
 	grad_request_t *greq;
 
-	log_open(L_ACCT);
+	log_open(GRAD_LOG_ACCT);
 	
         if (suspend_flag) {
 		stat_inc(acct, ntohl(clt_sa->sin_addr.s_addr), num_dropped);
@@ -255,7 +254,7 @@ decrypt_pair(grad_request_t *req, grad_avp_t *pair)
 	if (pair->prop & GRAD_AP_ENCRYPT) {
 		char password[GRAD_STRING_LENGTH+1];
 		req_decrypt_password(password, req, pair);
-		grad_free(pair->avp_strvalue);
+		free(pair->avp_strvalue);
 		pair->avp_strvalue = grad_estrdup(password);
 		pair->avp_strlength = strlen(pair->avp_strvalue);
 	}
@@ -292,10 +291,8 @@ radius_destroy_pairs(grad_avp_t **p)
 static grad_avp_t *
 _extract_pairs(grad_request_t *req, int prop)
 {
-	int i;
 	grad_avp_t *newlist = NULL;
 	grad_avp_t *pair;
-	char password[GRAD_STRING_LENGTH+1];
 	int found = 0;
 	
 	for (pair = req->avlist; !found && pair; pair = pair->next)
@@ -425,7 +422,7 @@ radius_req_drop(int type, void *data, void *orig_data,
 {
 	radiusd_request_t *radreq = data ? data : orig_data;
 
-        grad_log_req(L_NOTICE, radreq->request,
+        grad_log_req(GRAD_LOG_NOTICE, radreq->request,
 		     "%s: %s", _("Dropping packet"),  status_str);
 
         switch (type) {
@@ -448,7 +445,7 @@ radius_req_xmit(REQUEST *request)
 		} else {
 			radius_send_reply(0, req,
 					  NULL, NULL, request->fd);
-			grad_log_req(L_NOTICE, req->request,
+			grad_log_req(GRAD_LOG_NOTICE, req->request,
 				     _("Retransmitting %s reply"),
 				     request_class[request->type].name);
 		} 
@@ -520,7 +517,8 @@ radius_respond(REQUEST *req)
 	case RT_ACCESS_CHALLENGE:
 		if (!req->orig) {
 			char buf[GRAD_MAX_SHORTNAME];
-			grad_log_req(L_PROXY|L_ERR, radreq->request,
+			grad_log_req(GRAD_LOG_PROXY|GRAD_LOG_ERR, 
+			             radreq->request,
 				     _("Unrecognized proxy reply from server %s, proxy ID %d"),
 				     client_lookup_name(radreq->request->ipaddr,
 						        buf, sizeof buf), 
@@ -554,7 +552,7 @@ radius_respond(REQUEST *req)
 
         default:
                 stat_inc(acct, radreq->request->ipaddr, num_unknowntypes);
-                grad_log_req(L_NOTICE, radreq->request,
+                grad_log_req(GRAD_LOG_NOTICE, radreq->request,
 			     _("unknown request code %d"), 
                              radreq->request->code); 
                 return -1;
@@ -655,6 +653,6 @@ radius_trace_path(radiusd_request_t *req)
 	td.file = NULL;
 	grad_list_iterate(req->locus_list, _trace_path_compose, &td);
 	p = obstack_finish(&td.stk);
-	grad_log_req(L_INFO, req->request, _("rule trace: %s"), p);
+	grad_log_req(GRAD_LOG_INFO, req->request, _("rule trace: %s"), p);
 	obstack_free(&td.stk, NULL);
 }
