@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,2007,
-   2008 Free Software Foundation
+   Copyright (C) 2000-2025 Free Software Foundation
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,8 +12,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -162,11 +160,11 @@ unsigned process_timeout = PROCESS_TIMEOUT;
 unsigned radiusd_write_timeout = RADIUSD_WRITE_TIMEOUT;
 unsigned radiusd_read_timeout = RADIUSD_READ_TIMEOUT;
 
-grad_uint32_t warning_seconds;
+uint32_t warning_seconds;
 int use_guile;
 char *message_text[MSG_COUNT];
-grad_uint32_t myip = INADDR_ANY;
-grad_uint32_t ref_ip = INADDR_ANY;
+uint32_t myip = INADDR_ANY;
+uint32_t ref_ip = INADDR_ANY;
 int auth_port;
 int acct_port;
 
@@ -179,9 +177,9 @@ char **xargv;
 char *x_debug_spec;
 
 /* Forward declarations */
-static RETSIGTYPE sig_handler(int sig);
-void radiusd_main_loop();
-static size_t radius_count_channels();
+static void sig_handler(int sig);
+void radiusd_main_loop(void);
+static size_t radius_count_channels(void);
 void radiusd_run_preconfig_hooks(void *data);
 struct cfg_stmt config_syntax[];
 
@@ -311,7 +309,7 @@ static struct argp argp = {
 
 /* *********************** Configuration Functions ************************* */
 void
-set_config_defaults()
+set_config_defaults(void)
 {
         username_valid_chars = grad_estrdup(".-_!@#$%^&\\/");
         message_text[MSG_ACCOUNT_CLOSED] =
@@ -357,7 +355,7 @@ max_ttl(time_t *t)
 }
 
 static void
-terminate_subprocesses()
+terminate_subprocesses(void)
 {
 	int kill_sent = 0;
 	time_t t;
@@ -420,7 +418,7 @@ daemon_postconfig_hook(void *a ARG_UNUSED, void *b ARG_UNUSED)
 }
 
 void
-radiusd_setup()
+radiusd_setup(void)
 {
 	int i;
 
@@ -429,7 +427,7 @@ radiusd_setup()
                 close(i);
         /* Determine default port numbers for authentication and accounting */
 	if (auth_port == 0) 
-		auth_port = get_port_number("radius", "udp", DEF_AUTH_PORT);
+		auth_port = get_port_number("radius", "udp", RADIUS_AUTH_PORT);
 	if (acct_port == 0)
 		acct_port = get_port_number("radacct", "udp", auth_port+1);
 #ifdef USE_SNMP
@@ -457,13 +455,14 @@ radiusd_setup()
 
 	rewrite_init();
 	dynload_init();
-        snmp_init(0, 0, (snmp_alloc_t)grad_emalloc, (snmp_free_t)grad_free);
+        snmp_init(0, 0, (snmp_alloc_t)grad_emalloc, (snmp_free_t)free);
 	mlc_init();
 	sql_init();
+	guile_init();
 }
 
 void
-common_init()
+common_init(void)
 {
 	grad_log(GRAD_LOG_INFO, _("Starting"));
 
@@ -477,9 +476,7 @@ common_init()
 			      udp_input_handler,
 			      udp_input_close,
 			      udp_input_cmp);
-#ifdef HAVE_SETVBUF
         setvbuf(stdout, NULL, _IOLBF, 0);
-#endif
 	radiusd_signal_init(sig_handler);
 	forward_init();
 #ifdef USE_SNMP
@@ -510,7 +507,7 @@ common_init()
 
 /* ************************** Core of radiusd ****************************** */
 void
-radiusd_daemon()
+radiusd_daemon(void)
 {
         char *p;
         int i;
@@ -526,9 +523,8 @@ radiusd_daemon()
                 exit(0);
         }
                 
-#ifdef HAVE_SETSID
         setsid();
-#endif
+
         /* SIGHUP is ignored because when the session leader terminates
            all process in the session are sent the SIGHUP.  */
         grad_set_signal(SIGHUP, SIG_IGN);
@@ -561,11 +557,11 @@ radiusd_daemon()
                 fflush(stdout);
                 fflush(stderr);
         } 	
-        grad_free(p);
+        free(p);
 }
 
 int
-radiusd_master()
+radiusd_master(void)
 {
 	return radiusd_pid == getpid();
 }
@@ -574,7 +570,7 @@ radiusd_master()
 /* ****************************** Main function **************************** */
 
 void
-radiusd_main()
+radiusd_main(void)
 {
         switch (radius_mode) {
         case MODE_CHECKCONF:
@@ -617,23 +613,13 @@ radiusd_main()
 		log_change_owner(&radiusd_user);
 		p = grad_mkfilename(grad_log_dir, "radius.stderr");
 		chown(p, radiusd_user.uid, radiusd_user.gid);
-		grad_free(p);
+		free(p);
 		radius_switch_to_user(&radiusd_user);
 	}
 
         radiusd_main_loop();
 }
 
-void
-radiusd_start()
-{
-#ifdef USE_SERVER_GUILE
-	scheme_main();
-#else
-	radiusd_main();
-#endif
-}
-
 int
 main(int argc, char **argv)
 {
@@ -665,12 +651,12 @@ main(int argc, char **argv)
                 log_set_to_console(-1, console_logging_priority);
 
 	radiusd_setup();
-	radiusd_start();
+	radiusd_main();
 	/*NOTREACHED*/
 }
 
 static int
-snmp_request_to_command()
+snmp_request_to_command(void)
 {
 #ifdef USE_SNMP
 	if (server_stat && server_stat->auth.status != saved_status) {
@@ -700,7 +686,7 @@ snmp_request_to_command()
 }
 
 void
-radiusd_suspend()
+radiusd_suspend(void)
 {
 	if (suspend_flag == 0) {
 		terminate_subprocesses();
@@ -710,7 +696,7 @@ radiusd_suspend()
 }
 
 void
-radiusd_continue()
+radiusd_continue(void)
 {
 	if (suspend_flag) {
 		terminate_subprocesses();
@@ -723,7 +709,7 @@ radiusd_continue()
 }
 
 static void
-check_reload()
+check_reload(void)
 {
 	if (daemon_command == CMD_NONE)
 		daemon_command = snmp_request_to_command();
@@ -779,7 +765,7 @@ radiusd_close_channel(int fd)
 }
 
 void
-radiusd_collect_children()
+radiusd_collect_children(void)
 {
 	pid_t pid;
 	int status;
@@ -793,13 +779,13 @@ radiusd_collect_children()
 }
 
 void
-radiusd_cleanup()
+radiusd_cleanup(void)
 {
 	rpp_collect_exited ();
 }
 
 void
-radiusd_restart()
+radiusd_restart(void)
 {
 	pid_t pid;
 	
@@ -859,7 +845,7 @@ radiusd_rpp_wait(void *arg)
 }
 
 void
-radiusd_flush_queue()
+radiusd_flush_queue(void)
 {
 	time_t t;
 	max_ttl(&t);
@@ -867,7 +853,7 @@ radiusd_flush_queue()
 }
 		
 void
-radiusd_exit()
+radiusd_exit(void)
 {
         stat_done();
 	radiusd_pidfile_remove(RADIUSD_PID_FILE);
@@ -880,14 +866,14 @@ radiusd_exit()
 }
 
 void
-radiusd_exit0()
+radiusd_exit0(void)
 {
         radiusd_sql_shutdown();
         exit(0);
 }
 
 void
-radiusd_main_loop()
+radiusd_main_loop(void)
 {
         grad_log(GRAD_LOG_INFO, _("Ready to process requests."));
 
@@ -947,7 +933,7 @@ _hook_call(void *item, void *data)
 	hp->function(hp->data, clos->call_data);
 	if (hp->once) {
 		grad_list_remove(clos->list, hp, NULL);
-		grad_free(hp);
+		free(hp);
 	}
 	return 0;
 }
@@ -971,7 +957,7 @@ radiusd_run_postconfig_hooks(void *data)
 }
 
 void
-radiusd_reconfigure()
+radiusd_reconfigure(void)
 {
         int rc = 0;
         char *filename;
@@ -982,7 +968,7 @@ radiusd_reconfigure()
 	/* Read main configuration file */
         filename = grad_mkfilename(grad_config_dir, RADIUS_CONFIG);
         cfg_read(filename, config_syntax, NULL);
-	grad_free(filename);
+	free(filename);
 
 	/* Read other files */
         rc = reload_config_file(reload_all);
@@ -999,7 +985,7 @@ radiusd_reconfigure()
 
 /* ***************************** Signal Handling *************************** */
 
-static RETSIGTYPE
+static void
 sig_handler(int sig)
 {
         switch (sig) {
@@ -1037,7 +1023,7 @@ sig_handler(int sig)
 }
 
 void
-radiusd_signal_init(RETSIGTYPE (*hp)(int sig))
+radiusd_signal_init(void (*hp)(int sig))
 {
 	static int signum[] = {
 		SIGHUP, SIGUSR1, SIGUSR2, SIGCHLD, 
@@ -1062,7 +1048,7 @@ radiusd_pidfile_write(char *name)
                 fprintf(fp, "%lu\n", (u_long) pid);
                 fclose(fp);
         }
-        grad_free(p);
+        free(p);
 }	
 
 pid_t
@@ -1076,7 +1062,7 @@ radiusd_pidfile_read(char *name)
 	if (fscanf(fp, "%lu", &val) != 1)
 		val = -1;
 	fclose(fp);
-	grad_free(p);
+	free(p);
 	return (pid_t) val;
 }
 
@@ -1085,13 +1071,13 @@ radiusd_pidfile_remove(char *name)
 {
 	char *p = grad_mkfilename(grad_pid_dir, name);
 	unlink(p);
-	grad_free(p);
+	free(p);
 }
 
 
 
 /* ************************************************************************* */
-static u_char recv_buffer[RAD_BUFFER_SIZE];
+static char recv_buffer[RAD_BUFFER_SIZE];
 
 struct udp_data {
 	int type;
@@ -1129,7 +1115,7 @@ int
 udp_input_close(int fd, void *data)
 {
 	close(fd);
-	grad_free(data);
+	free(data);
 	return 0;
 }
 
@@ -1148,7 +1134,7 @@ udp_input_cmp(const void *a, const void *b)
 }
 
 int
-udp_open(int type, grad_uint32_t ipaddr, int port, int nonblock)
+udp_open(int type, uint32_t ipaddr, int port, int nonblock)
 {
 	int fd;
 	struct sockaddr_in s;
@@ -1232,7 +1218,7 @@ channel_counter(void *item, void *data)
 }
 
 static size_t
-radius_count_channels()
+radius_count_channels(void)
 {
 	size_t count = 0;
 	
@@ -1253,7 +1239,7 @@ rad_cfg_listen_auth(int argc, cfg_value_t *argv,
 	int i, errcnt = 0;
 
 	if (argc == 2 && argv[1].type == CFG_BOOLEAN) {
-		if (argv[1].v.bool == 0)
+		if (argv[1].v.boolean == 0)
 			auth_port = 0;
 		return 0;
 	}
@@ -1269,7 +1255,7 @@ rad_cfg_listen_auth(int argc, cfg_value_t *argv,
 	
 	if (errcnt == 0 && radius_mode == MODE_DAEMON) {
 		for (i = 1; i < argc; i++) {
-			grad_uint32_t ip;
+			uint32_t ip;
 			int port;
 
 			if (argv[i].type == CFG_NETWORK) {
@@ -1308,7 +1294,7 @@ rad_cfg_listen_acct(int argc, cfg_value_t *argv,
 	int i, errcnt = 0;
 	
 	if (argc == 2 && argv[1].type == CFG_BOOLEAN) {
-		if (argv[1].v.bool == 0)
+		if (argv[1].v.boolean == 0)
 			acct_port = 0;
 		return 0;
 	}
@@ -1324,7 +1310,7 @@ rad_cfg_listen_acct(int argc, cfg_value_t *argv,
 	
 	if (errcnt == 0 && radius_mode == MODE_DAEMON) {
 		for (i = 1; i < argc; i++) {
-			grad_uint32_t ip;
+			uint32_t ip;
 			int port;
 
 			if (argv[i].type == CFG_NETWORK) {
@@ -1363,8 +1349,7 @@ rad_cfg_user(int argc, cfg_value_t *argv,
 
 	if (argc != 2 || argv[1].type != CFG_STRING) 
 		return 1;
-	return radius_get_user_ids((RADIUS_USER *) handler_data,
-				   argv[1].v.string);
+	return radius_get_user_ids(usr, argv[1].v.string);
 }
 
 int
@@ -1372,7 +1357,7 @@ option_stmt_end(void *block_data, void *handler_data)
 {
 	if (exec_user.username && radiusd_user.uid != 0) {
 		grad_log(GRAD_LOG_WARN, _("Ignoring exec-program-user"));
-		grad_free(exec_user.username);
+		free(exec_user.username);
 		exec_user.username = NULL;
 	} else if (exec_user.username == NULL
 		   && radiusd_user.uid == 0 && getuid() == 0)
