@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius
-   Copyright (C) 2000,2002,2003,2004,2005,2007,
-   2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -24,6 +22,7 @@
 
 #include <stdlib.h>
 #include <ctype.h>
+#include <inttypes.h>
 
 #include <sysdep.h>
 #include <radiusd.h>
@@ -181,7 +180,7 @@ attr_to_str(struct obstack *obp, grad_request_t *req, grad_avp_t *pairlist,
                         dval = NULL;
                 
                 if (!dval) {
-			snprintf(tmp, sizeof(tmp), "%lu", pair->avp_lvalue);
+			snprintf(tmp, sizeof(tmp), "%"PRIu32, pair->avp_lvalue);
 			len = strlen(tmp);
 			obstack_grow(obp, tmp, len);
 		} else 
@@ -196,7 +195,7 @@ attr_to_str(struct obstack *obp, grad_request_t *req, grad_avp_t *pairlist,
                 break;
 		
         case GRAD_TYPE_DATE:
-                snprintf(tmp, sizeof(tmp), "%ld", pair->avp_lvalue);
+                snprintf(tmp, sizeof(tmp), "%"PRIu32, pair->avp_lvalue);
                 len = strlen(tmp);
                 obstack_grow(obp, tmp, len);
                 break;
@@ -220,7 +219,7 @@ curtime_to_str(struct obstack *obp, grad_avp_t *request, int gmt)
         int len;
         
         curtime = time(NULL);
-        if (pair = grad_avl_find(request, DA_ACCT_DELAY_TIME))
+        if ((pair = grad_avl_find(request, DA_ACCT_DELAY_TIME)) != NULL)
                 curtime -= pair->avp_lvalue;
         if (gmt)
                 tm = gmtime(&curtime);
@@ -398,7 +397,7 @@ radius_xlate0(struct obstack *obp, char *str, grad_request_t *req,
                                 da = parse_dict_attr(p, &p, &defval);
                                 attr_to_str(obp, req, req->avlist,
                                             da, defval, escape);
-                                grad_free(defval);
+                                free(defval);
                                 break;
 				
                         case 'R':
@@ -508,7 +507,7 @@ pair_set_value(grad_avp_t *p, grad_value_t *val)
 	case Integer:
 		switch (p->type) {
 		case GRAD_TYPE_STRING:
-			snprintf(buf, sizeof buf, "%lu", val->datum.ival);
+			snprintf(buf, sizeof buf, "%"PRIu32, val->datum.ival);
 			grad_string_replace(&p->avp_strvalue, buf);
 			p->avp_strlength = strlen(p->avp_strvalue);
 			break;
@@ -621,11 +620,11 @@ void
 radiusd_request_free(radiusd_request_t *radreq)
 {
 	grad_list_destroy(&radreq->locus_list, NULL, NULL);
-	grad_free(radreq->remote_user);
+	free(radreq->remote_user);
         grad_avl_free(radreq->reply_pairs);
-        grad_free(radreq->reply_msg);
+        free(radreq->reply_msg);
         grad_avl_free(radreq->server_reply);
 	grad_request_free(radreq->request);
-	grad_free(radreq);
+	free(radreq);
 }
 
