@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2002,2003,2004,2006,2007 Free Software Foundation, Inc.
+   Copyright (C) 2002-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -74,12 +73,13 @@ REQUEST *
 request_create(int type, int fd,
 	       const struct sockaddr_in *srv_sa,
 	       const struct sockaddr_in *clt_sa,
-	       u_char *buf, size_t bufsize)
+	       char *buf, size_t bufsize)
 {
 	void *data;
 	REQUEST *req;
 
-	if (request_class[type].decode(srv_sa, clt_sa, buf, bufsize, &data))
+	if (request_class[type].decode(srv_sa, clt_sa, (u_char*)buf, bufsize,
+				       &data))
 		return NULL;
 	req = grad_emalloc(sizeof *req);
 	req->data = data;
@@ -101,8 +101,8 @@ request_free(REQUEST *req)
 {
 	if (req) {
 		request_class[req->type].free(req->data);
-		grad_free(req->rawdata);
-		grad_free(req);
+		free(req->rawdata);
+		free(req);
 	}
 }
 
@@ -162,7 +162,7 @@ request_forward(REQUEST *req)
 int
 request_retransmit(REQUEST *req, void *rawdata, size_t rawsize)
 {
-	grad_free(req->rawdata);
+	free(req->rawdata);
 	req->rawdata = grad_emalloc(rawsize);
 	memcpy(req->rawdata, rawdata, rawsize);
 	req->rawsize = rawsize;
@@ -221,7 +221,7 @@ _request_iterator(void *item, void *clos)
 			request_free(req);
 		} else if (req->timestamp + request_class[req->type].ttl
 			   <= rp->curtime) {
-			grad_log(L_NOTICE,
+			grad_log(GRAD_LOG_NOTICE,
 			         _("Proxy %s request expired in queue"),
 			         request_class[req->type].name);
 			grad_list_remove(request_list, req, NULL);
@@ -240,12 +240,12 @@ _request_iterator(void *item, void *clos)
 				pid_t pid = rpp_check_pid(req->child_id);
 				if (pid == req->child_id) {
 					if (rpp_kill(req->child_id, SIGKILL) == 0) { 
-						grad_log(L_NOTICE,
+						grad_log(GRAD_LOG_NOTICE,
 							 _("Killing unresponsive %s child %lu"),
 							 request_class[req->type].name,
 							 (unsigned long) req->child_id);
 					} else {
-						grad_log(L_CRIT,
+						grad_log(GRAD_LOG_CRIT,
 							 _("Cannot terminate child %lu. Attempting to kill inexisting process?"),
 							 (unsigned long) req->child_id);
 					}
@@ -255,7 +255,7 @@ _request_iterator(void *item, void *clos)
 			} else {
 				int rc = rpp_kill(req->child_id, SIGTERM);
 
-				grad_log(L_NOTICE,
+				grad_log(GRAD_LOG_NOTICE,
 					 _("Terminating unresponsive %s child %lu, status: %s"),
 					 request_class[req->type].name,
 					 (unsigned long) req->child_id,
@@ -439,7 +439,7 @@ _destroy_request(void *item, void *data)
 }
 
 void
-request_init_queue()
+request_init_queue(void)
 {
 	grad_list_destroy(&request_list, _destroy_request, NULL);
 }
