@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2006,
-   2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #if defined(HAVE_CONFIG_H)
 # include <config.h>
@@ -45,7 +43,7 @@ int variable_cmp(struct snmp_var *v1, struct snmp_var *v2);
 static grad_nas_t *nas_lookup_index(int ind);
 static void snmpserv_before_config_hook(void *unused1, void *unused2);
 static void snmpserv_after_config_hook(void *arg, void *unused);
-static void snmp_tree_init();
+static void snmp_tree_init(void);
 
 static grad_list_t /* of ACL */ *snmp_acl;
 static grad_list_t /* of Community */ *commlist;
@@ -74,7 +72,7 @@ netname_find(char *name)
 static int
 _netdef_destroy(void *item, void *data ARG_UNUSED)
 {
-	grad_free(item);
+	free(item);
 	return 0;
 }
 
@@ -82,14 +80,14 @@ static int
 _netname_destroy(void *item, void *data ARG_UNUSED)
 {
 	NETNAME *p = item;
-	grad_free(p->name);
+	free(p->name);
 	grad_list_destroy(&p->netlist, _netdef_destroy, NULL);
-	grad_free(p);
+	free(p);
 	return 0;
 }
 
 static void
-netgrad_list_destroy()
+netgrad_list_destroy(void)
 {
 	grad_list_destroy(&netlist, _netname_destroy, NULL);
 }
@@ -127,19 +125,19 @@ static int
 _community_destroy(void *item, void *data)
 {
 	Community *p = item;
-	grad_free(p->name);
-	grad_free(p);
+	free(p->name);
+	free(p);
 	return 0;
 }
 
 void
-snmp_free_communities()
+snmp_free_communities(void)
 {
 	grad_list_destroy(&commlist, _community_destroy, NULL);
 }
 
 struct acl_closure {
-	grad_uint32_t ip;
+	uint32_t ip;
 	char *community;
 	int access;
 };
@@ -172,7 +170,7 @@ _acl_iterator(void *item, void *data)
 }
 
 int
-check_acl(grad_uint32_t ip, char *community)
+check_acl(uint32_t ip, char *community)
 {
 	struct acl_closure clos;
 
@@ -199,12 +197,12 @@ snmp_add_acl(Community *community, grad_list_t /* of grad_netdef_t */ *netlist)
 static int
 _acl_destroy(void *item, void *data)
 {
-	grad_free(item);
+	free(item);
 	return 0;
 }
 		
 void
-snmp_free_acl()
+snmp_free_acl(void)
 {
 	grad_list_destroy(&snmp_acl, _acl_destroy, NULL);
 }
@@ -242,7 +240,7 @@ snmp_cfg_ident(int argc, cfg_value_t *argv, void *block_data,
 		return 0;
 	}
 	if (server_id)
-		grad_free(server_id);
+		free(server_id);
 	server_id = grad_estrdup(argv[1].v.string);
 	return 0;
 }
@@ -277,7 +275,7 @@ snmp_cfg_community(int argc, cfg_value_t *argv,
 		return 1;
 		
 	if (snmp_find_community(argv[1].v.string)) {
-		grad_log(L_ERR,
+		grad_log(GRAD_LOG_ERR,
 		         _("%s:%d: community %s already declared"),
 		         cfg_filename, cfg_line_num, argv[1].v.string);
 		return 0;
@@ -294,7 +292,7 @@ snmp_cfg_listen(int argc, cfg_value_t *argv,
 	int i, errcnt = 0;
 	
 	if (argc == 2 && argv[1].type == CFG_BOOLEAN) {
-		if (argv[1].v.bool == 0)
+		if (argv[1].v.boolean == 0)
 			snmp_port = 0;
 		return 0;
 	}
@@ -335,14 +333,14 @@ snmp_cfg_network(int argc, cfg_value_t *argv,
 
         np = grad_emalloc(sizeof(*np));
 	if (!netlist) 
-		netlist = grad_list_create(netlist);
+		netlist = grad_list_create();
 		
 	grad_list_append(netlist, np);
         np->name = grad_estrdup(argv[1].v.string);
 	np->netlist = grad_list_create();
 	for (i = 2; i < argc; i++) {
 		if (argv[i].type != CFG_NETWORK) {
-			grad_log(L_ERR,
+			grad_log(GRAD_LOG_ERR,
 			         _("%s:%d: list item %d has wrong datatype"),
 			         cfg_filename, cfg_line_num,
 			         i);
@@ -374,14 +372,14 @@ snmp_cfg_allow(int argc, cfg_value_t *argv,
 	}
 
 	if ((nn = netname_find(argv[1].v.string)) == NULL) {
-		grad_log(L_ERR, _("%s:%d: no such network: %s"),
+		grad_log(GRAD_LOG_ERR, _("%s:%d: no such network: %s"),
 		         cfg_filename, cfg_line_num, argv[1].v.string);
 		return 0;
 	}
 
 	comm = snmp_find_community(argv[2].v.string);
 	if (!comm) {
-		grad_log(L_ERR, 
+		grad_log(GRAD_LOG_ERR, 
 		         _("%s:%d: undefined community %s"),
 		         cfg_filename, cfg_line_num, argv[2].v.string);
 		return 0;
@@ -408,7 +406,7 @@ snmp_cfg_deny(int argc, cfg_value_t *argv,
 	}
 
 	if ((nn = netname_find(argv[1].v.string)) == NULL) {
-		grad_log(L_ERR, _("%s:%d: no such network: %s"),
+		grad_log(GRAD_LOG_ERR, _("%s:%d: no such network: %s"),
 		         cfg_filename, cfg_line_num, argv[1].v.string);
 		return 0;
 	}
@@ -560,7 +558,7 @@ union snmpserv_data {
 static union snmpserv_data *__snmpserv_data;
 
 static void *
-snmpserv_get_data()
+snmpserv_get_data(void)
 {
         if (!__snmpserv_data) {
                 __snmpserv_data = grad_emalloc(sizeof(*__snmpserv_data));
@@ -735,12 +733,12 @@ static struct mib_data {
 };                                          
 
 void
-snmp_tree_init()
+snmp_tree_init(void)
 {
         struct mib_data *p;
         struct mib_node_t *node;
         
-        snmp_init(0, 0, (snmp_alloc_t)grad_emalloc, (snmp_free_t)grad_free);
+        snmp_init(0, 0, (snmp_alloc_t)grad_emalloc, (snmp_free_t)free);
 
         for (p = mib_data; p < mib_data + GRAD_NITEMS(mib_data); p++) {
                 mib_insert(&mib_tree, p->oid, &node);
@@ -754,7 +752,7 @@ snmp_tree_init()
 /* Mark reset of the auth server. Do not do any real work, though.
  */
 void
-snmp_auth_server_reset()
+snmp_auth_server_reset(void)
 {
         struct timeval tv;
         struct timezone tz;
@@ -766,7 +764,7 @@ snmp_auth_server_reset()
 /* Mark reset of the acct server. Again, no real work, please.
  */
 void
-snmp_acct_server_reset()
+snmp_acct_server_reset(void)
 {
         struct timeval tv;
         struct timezone tz;
@@ -849,8 +847,7 @@ mib_down(struct mib_node_t *node, oid_t oid)
 int
 mib_get_next(struct mib_node_t *node, struct snmp_var **varp, int *errp)
 {
-        int rc;
-        oid_t oid = (*varp)->name;
+	oid_t oid = (*varp)->name;
         char buf[MAXOIDLEN];
         struct snmp_var *temp_var;
         struct mib_node_t *found_node;
@@ -859,7 +856,11 @@ mib_get_next(struct mib_node_t *node, struct snmp_var **varp, int *errp)
                     sprint_oid(buf, sizeof(buf), (*varp)->name));
         
         /* first, find the node itself */
-        rc = mib_lookup(node, oid, OIDLEN(oid), &found_node);
+        if (mib_lookup(node, oid, OIDLEN(oid), &found_node)
+	    != MIB_MATCH_EXACT) {
+                *errp = SNMP_ERR_NOSUCHNAME;
+                return -1;
+        }
 
         *errp = SNMP_ERR_NOERROR;
 
@@ -888,7 +889,7 @@ mib_get_next(struct mib_node_t *node, struct snmp_var **varp, int *errp)
                         GRAD_DEBUG2(2, "rolling back from %d:%d",
                                     found_node->index,
                                     found_node->subid);
-                        while (node = found_node->up) {
+                        while ((node = found_node->up) != NULL) {
                                 mib_reset(node);
                                 if (node->down && node->down != found_node)
                                         break;
@@ -1143,7 +1144,7 @@ timeval_diff(struct timeval *tva, struct timeval *tvb)
 }
 
 serv_stat
-abridge_server_state()
+abridge_server_state(void)
 {
         switch (server_stat->auth.status) {
         case serv_init:
@@ -1208,8 +1209,8 @@ snmp_auth_var_get(subid_t subid, oid_t oid, int *errp)
                 p = make_server_ident();
                 ret->type = ASN_OCTET_STR;
                 ret->val_length = strlen(p);
-                ret->var_str = snmp_strdup(p);
-                grad_free(p);
+                ret->var_str = (u_char*) snmp_strdup(p);
+                free(p);
                 break;
 
         case MIB_KEY_AuthServUpTime:
@@ -1327,7 +1328,7 @@ snmp_auth_var_set(subid_t subid, struct snmp_var **vp, int *errp)
                         
                 case MIB_KEY_AccServConfigReset:
                         server_stat->auth.status = serv_init;
-                        grad_log(L_INFO,
+                        grad_log(GRAD_LOG_INFO,
                                  _("acct server re-initializing on SNMP request"));
                         break;
 
@@ -1445,15 +1446,15 @@ get_auth_nasstat(grad_nas_t *nas, struct snmp_var *var, int key)
                 
         case MIB_KEY_AuthClientAddress:
                 var->type = SMI_IPADDRESS;
-                var->val_length = sizeof(grad_uint32_t);
-                var->var_str = snmp_alloc(sizeof(grad_uint32_t));
-                *(grad_uint32_t*)var->var_str = ntohl(statp->ipaddr);
+                var->val_length = sizeof(uint32_t);
+                var->var_str = snmp_alloc(sizeof(uint32_t));
+                *(uint32_t*)var->var_str = ntohl(statp->ipaddr);
                 break;
 
         case MIB_KEY_AuthClientID:
                 var->type = ASN_OCTET_STR;
                 var->val_length = strlen(nas->longname);
-                var->var_str = snmp_strdup(nas->longname);
+                var->var_str = (u_char*) snmp_strdup(nas->longname);
                 break;
 
         case MIB_KEY_AuthServAccessRequests:
@@ -1567,8 +1568,8 @@ snmp_acct_var_get(subid_t subid, oid_t oid, int *errp)
                 p = make_server_ident();
                 ret->type = ASN_OCTET_STR;
                 ret->val_length = strlen(p);
-                ret->var_str = snmp_strdup(p);
-                grad_free(p);
+                ret->var_str = (u_char*) snmp_strdup(p);
+                free(p);
                 break;
 
         case MIB_KEY_AccServUpTime:
@@ -1679,7 +1680,7 @@ snmp_acct_var_set(subid_t subid, struct snmp_var **vp, int *errp)
 
                 case MIB_KEY_AuthServConfigReset:
                         server_stat->auth.status = serv_init;
-                        grad_log(L_INFO,
+                        grad_log(GRAD_LOG_INFO,
                                  _("auth server re-initializing on SNMP request"));
                         break;
 
@@ -1783,15 +1784,15 @@ get_acct_nasstat(grad_nas_t *nas, struct snmp_var *var, int key)
 
         case MIB_KEY_AccClientAddress:
                 var->type = SMI_IPADDRESS;
-                var->val_length = sizeof(grad_uint32_t);
-                var->var_str = snmp_alloc(sizeof(grad_uint32_t));
-                *(grad_uint32_t*)var->var_str = ntohl(statp->ipaddr);
+                var->val_length = sizeof(uint32_t);
+                var->var_str = snmp_alloc(sizeof(uint32_t));
+                *(uint32_t*)var->var_str = ntohl(statp->ipaddr);
                 break;
 
         case MIB_KEY_AccClientID:
                 var->type = ASN_OCTET_STR;
                 var->val_length = strlen(nas->longname);
-                var->var_str = snmp_strdup(nas->longname);
+                var->var_str = (u_char*) snmp_strdup(nas->longname);
                 break;
 
         case MIB_KEY_AccServPacketsDropped:
@@ -1959,23 +1960,23 @@ snmp_serv_var_set(subid_t subid, struct snmp_var **vp, int *errp)
                         server_stat->auth.status = (*vp)->var_int;
                         switch ((*vp)->var_int) {
                         case serv_reset:
-                                grad_log(L_NOTICE,
+                                grad_log(GRAD_LOG_NOTICE,
                                          _("server re-initializing on SNMP request"));
                                 break;
                         case serv_init:
-                                grad_log(L_NOTICE,
+                                grad_log(GRAD_LOG_NOTICE,
                                          _("server restart on SNMP request"));
                                 break;
                         case serv_running:
-                                grad_log(L_NOTICE,
+                                grad_log(GRAD_LOG_NOTICE,
                                          _("server continuing on SNMP request"));
                                 break;
                         case serv_suspended:
-                                grad_log(L_NOTICE,
+                                grad_log(GRAD_LOG_NOTICE,
                                          _("server suspending on SNMP request"));
                                 break;
                         case serv_shutdown:
-                                grad_log(L_NOTICE,
+                                grad_log(GRAD_LOG_NOTICE,
                                          _("server shutting down on SNMP request"));
                                 break;
                         }
@@ -2040,8 +2041,8 @@ snmp_stat_var_get(subid_t subid, oid_t oid, int *errp)
                 p = make_server_ident();
                 ret->type = ASN_OCTET_STR;
                 ret->val_length = strlen(p);
-                ret->var_str = snmp_strdup(p);
-                grad_free(p);
+                ret->var_str = (u_char*) snmp_strdup(p);
+                free(p);
                 break;
 
         case MIB_KEY_StatUpTime:
@@ -2093,7 +2094,7 @@ snmp_stat_nas(int num, enum mib_node_cmd cmd, struct nas_data *closure,
 {
         grad_nas_t *nas;
         struct nas_stat *nsp;
-        grad_uint32_t ip;
+        uint32_t ip;
         struct snmp_var *var;
         int len;
         
@@ -2168,7 +2169,7 @@ snmp_stat_nas(int num, enum mib_node_cmd cmd, struct nas_data *closure,
                 
         case MIB_NODE_RESET:
                 if (num == 0) {
-                        if (nas = nas_lookup_index(1))
+                        if ((nas = nas_lookup_index(1)) != NULL)
                                 for (num = 0; num < 4; num++)
                                         closure->quad[num] =
 						(nas->netdef.ipaddr >>
@@ -2303,15 +2304,15 @@ get_stat_nasstat(grad_nas_t *nas, struct snmp_var *var, int ind)
         switch (ind) {
         case MIB_KEY_NASAddress:
                 var->type = SMI_IPADDRESS;
-                var->val_length = sizeof(grad_uint32_t);
-                var->var_str = snmp_alloc(sizeof(grad_uint32_t));
-                *(grad_uint32_t*)var->var_str = ntohl(statp->ipaddr);
+                var->val_length = sizeof(uint32_t);
+                var->var_str = snmp_alloc(sizeof(uint32_t));
+                *(uint32_t*)var->var_str = ntohl(statp->ipaddr);
                 break;
 
         case MIB_KEY_NASID:
                 var->type = ASN_OCTET_STR;
                 var->val_length = strlen(nas->longname);
-                var->var_str = snmp_strdup(nas->longname);
+                var->var_str = (u_char*) snmp_strdup(nas->longname);
                 break;
 
         case MIB_KEY_NASLines:
@@ -2517,7 +2518,7 @@ snmp_port_get(subid_t subid, struct snmp_var *var, int *errp)
         case MIB_KEY_StatPortInUseTotalTime:        
         case MIB_KEY_StatPortInUseMaxTime:     
         case MIB_KEY_StatPortInUseMaxTimestamp:       
-                if (port = findportbyindex(subid)) {
+                if ((port = findportbyindex(subid)) != NULL) {
                         get_port_stat(port, ret, key);
                         break;
                 }
@@ -2561,9 +2562,9 @@ get_port_stat(PORT_STAT *port, struct snmp_var *var, subid_t key)
 
         case MIB_KEY_StatPortFramedAddress:
                 var->type = SMI_IPADDRESS;
-                var->val_length = sizeof(grad_uint32_t);
-                var->var_str = snmp_alloc(sizeof(grad_uint32_t));
-                *(grad_uint32_t*)var->var_str = port->framed_address;
+                var->val_length = sizeof(uint32_t);
+                var->var_str = snmp_alloc(sizeof(uint32_t));
+                *(uint32_t*)var->var_str = port->framed_address;
                 break;
 
         case MIB_KEY_StatPortTotalLogins:                 
@@ -2594,7 +2595,7 @@ get_port_stat(PORT_STAT *port, struct snmp_var *var, subid_t key)
         case MIB_KEY_StatPortLastLoginName:             
                 var->type = ASN_OCTET_STR;
                 var->val_length = strlen(port->login);
-                var->var_str = snmp_strdup(port->login);
+                var->var_str = (u_char*) snmp_strdup(port->login);
                 break;
 
         case MIB_KEY_StatPortLastLoginTimestamp:
@@ -2674,20 +2675,20 @@ snmp_decode(SNMP_REQ *req, u_char *buf, size_t len)
         struct snmp_session sess;
         int access;
         char comm[128];
-        int comm_len;
+        u_int comm_len;
         char ipbuf[GRAD_IPV4_STRING_LENGTH];
         
-        log_open(L_SNMP);
+        log_open(GRAD_LOG_SNMP);
 	
         if ((pdu = snmp_pdu_create(0)) == NULL) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          _("can't create SNMP PDU: %s"),
                          snmp_strerror(snmp_errno));
                 return -1;
         }
         comm_len = sizeof(comm);
         if (snmp_decode_request(&sess, pdu, buf, len, comm, &comm_len)) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          _("can't decode SNMP packet from %s: %s"),
 		         grad_ip_iptostr(ntohl(req->addr.sin_addr.s_addr),
 				         ipbuf),
@@ -2697,7 +2698,7 @@ snmp_decode(SNMP_REQ *req, u_char *buf, size_t len)
 
         access = check_acl(req->addr.sin_addr.s_addr, comm);
         if (!access) {
-                grad_log(L_NOTICE,
+                grad_log(GRAD_LOG_NOTICE,
                          _("DENIED attempt to access community %s from %s"),
                          comm,
                          grad_ip_iptostr(ntohl(req->addr.sin_addr.s_addr), 
@@ -2711,15 +2712,16 @@ snmp_decode(SNMP_REQ *req, u_char *buf, size_t len)
 }
 
 int
-snmp_req_decode(struct sockaddr_in *sa,
-		  void *input, size_t inputsize, void **output)
+snmp_req_decode(const struct sockaddr_in *srv_sa,
+		const struct sockaddr_in *clt_sa,
+		void *input, size_t inputsize, void **output)
 {
         SNMP_REQ *req;
 
 	req = grad_emalloc(sizeof *req);
-	req->addr = *sa;
+	req->addr = *clt_sa;
         if (snmp_decode(req, input, inputsize)) {
-                grad_free(req);
+                free(req);
                 return 1;
         }
 	*output = req;
@@ -2740,8 +2742,8 @@ snmp_req_free(void *ptr)
 {
         SNMP_REQ *req = ptr;
         snmp_pdu_free(req->pdu);
-        grad_free(req->community);
-        grad_free(req);
+        free(req->community);
+        free(req);
 }
 
 void
@@ -2751,7 +2753,7 @@ snmp_req_drop(int type, void *data, void *orig_data,
         SNMP_REQ *req = data ? data : orig_data;
         char ipbuf[GRAD_IPV4_STRING_LENGTH];
 
-        grad_log(L_NOTICE,
+        grad_log(GRAD_LOG_NOTICE,
                  _("Dropping SNMP request from client %s: %s"),
                  grad_ip_iptostr(ntohl(req->addr.sin_addr.s_addr), ipbuf),
                  status_str);
@@ -2765,7 +2767,7 @@ snmp_req_respond(REQUEST *request)
 	SNMP_REQ *req = request->data;
 	struct snmp_session session;
         struct snmp_pdu *pdu;
-        int len;
+        u_int len;
 
         pdu = snmp_agent_response(req->pdu, req->access);
         if (pdu) {
