@@ -1,12 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006,2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #if defined(HAVE_CONFIG_H)
 # include <config.h>
@@ -32,6 +30,7 @@
 
 #ifdef USE_SERVER_GUILE
 # include <libguile.h>
+# include <radscm.h>
 #endif
 
 #if defined(USE_SQL)
@@ -42,13 +41,13 @@ static void detach_sql_connection(int type);
 static void sql_conn_destroy(struct sql_connection **conn);
 static void sql_cache_destroy(struct sql_connection *conn);
 
-static char *get_conf_line();
+static char *get_conf_line(void);
 static int get_boolean(char *str, int *retval);
 static char * sql_digest(SQL_cfg *cfg);
 static int sql_digest_comp(char *d1, char *d2);
 static int sql_cfg_comp(SQL_cfg *a, SQL_cfg *b);
 static int chop(char *str);
-static void sql_flush();
+static void sql_flush(void);
 
 SQL_cfg sql_cfg;
 static struct sql_connection *sql_conn[SQL_NSERVICE];
@@ -145,7 +144,7 @@ chop(char *str)
 }
 
 char *
-get_conf_line()
+get_conf_line(void)
 {
         char buf[256];
         char *ptr;
@@ -289,13 +288,13 @@ sql_cfg_comp(SQL_cfg *a, SQL_cfg *b)
         dig1 = sql_digest(a);
         dig2 = sql_digest(b);
         rc = sql_digest_comp(dig1, dig2);
-        grad_free(dig1);
-        grad_free(dig2);
+        free(dig1);
+        free(dig2);
         return rc;
 }
 
 int 
-radiusd_sql_config()
+radiusd_sql_config(void)
 {
         char *sqlfile;
         char *ptr;
@@ -303,7 +302,7 @@ radiusd_sql_config()
         SQL_cfg new_cfg;
 	int i;
 	
-#define FREE(a) if (a) grad_free(a); a = NULL
+#define FREE(a) do { free(a); a = NULL; } while (0)
 
         memset(&new_cfg, 0, sizeof(new_cfg));
         new_cfg.keepopen = 0;
@@ -314,8 +313,8 @@ radiusd_sql_config()
         sqlfile = grad_mkfilename(grad_config_dir, "sqlserver");
         /* Open source file */
         if ((sqlfd = fopen(sqlfile, "r")) == (FILE *) NULL) {
-                grad_log(L_ERR, _("could not read sqlserver file %s"), sqlfile);
-                grad_free(sqlfile);
+                grad_log(GRAD_LOG_ERR, _("could not read sqlserver file %s"), sqlfile);
+                free(sqlfile);
                 return -1;
         }
         line_no = 0;
@@ -323,7 +322,7 @@ radiusd_sql_config()
         obstack_init(&parse_stack);
         while (get_conf_line()) {
                 if (stmt_type == -1) {
-                        grad_log(L_ERR,
+                        grad_log(GRAD_LOG_ERR,
                                  "%s:%d: %s",
                                  sqlfile, line_no,
 			         _("unrecognized keyword"));
@@ -331,7 +330,7 @@ radiusd_sql_config()
                 }
                 /* Each keyword should have an argument */
                 if (cur_ptr == NULL) {
-                        grad_log(L_ERR,
+                        grad_log(GRAD_LOG_ERR,
                                  "%s:%d: %s",
                                  sqlfile, line_no,
 			         _("required argument missing"));
@@ -342,7 +341,7 @@ radiusd_sql_config()
                 case STMT_SERVER:
                        	if (cur_ptr[0] != '/'
 			    && !grad_ip_gethostaddr(cur_ptr)) {
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
                                          _("%s:%d: unknown host: %s"),
                                          sqlfile, line_no,
                                          cur_ptr);
@@ -356,7 +355,7 @@ radiusd_sql_config()
                 case STMT_PORT:
                         new_cfg.port = strtol(cur_ptr, &ptr, 0);
                         if (*ptr != 0 && !isspace(*ptr)) {
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
 				         "%s:%d: %s",
                                          sqlfile, line_no,
 				         _("number parse error"));
@@ -375,7 +374,7 @@ radiusd_sql_config()
                         
                 case STMT_KEEPOPEN:
                         if (get_boolean(cur_ptr, &new_cfg.keepopen))
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
                                          "%s:%d: %s",
                                          sqlfile, line_no,
 				         _("expected boolean value"));
@@ -384,7 +383,7 @@ radiusd_sql_config()
                 case STMT_IDLE_TIMEOUT:
                         timeout = strtol(cur_ptr, &ptr, 0);
                         if ((*ptr != 0 && !isspace(*ptr)) || timeout <= 0) {
-                                grad_log(L_ERR, "%s:%d: %s",
+                                grad_log(GRAD_LOG_ERR, "%s:%d: %s",
                                          sqlfile, line_no,
 				         _("number parse error"));
                         } else 
@@ -393,7 +392,7 @@ radiusd_sql_config()
                         
                 case STMT_DOAUTH:       
                         if (get_boolean(cur_ptr, &new_cfg.active[SQL_AUTH]))
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
                                          "%s:%d: %s",
                                          sqlfile, line_no,
 				         _("expected boolean value"));
@@ -401,7 +400,7 @@ radiusd_sql_config()
                         
                 case STMT_DOACCT:
                         if (get_boolean(cur_ptr, &new_cfg.active[SQL_ACCT]))
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
                                          "%s:%d: %s", 
                                          sqlfile, line_no,
 				         _("expected boolean value"));
@@ -416,21 +415,21 @@ radiusd_sql_config()
                         break;
                         
                 case STMT_MAX_AUTH_CONNECTIONS:
-                        grad_log(L_WARN,
+                        grad_log(GRAD_LOG_WARN,
                                  "%s:%d: %s",
                                  sqlfile, line_no,
 			         _("auth_max_connections is obsolete"));
                         break;
                         
                 case STMT_MAX_ACCT_CONNECTIONS:
-                        grad_log(L_WARN,
+                        grad_log(GRAD_LOG_WARN,
                                  "%s:%d: %s",
                                  sqlfile, line_no,
 			         _("acct_max_connections is obsolete"));
                         break;
                         
                 case STMT_QUERY_BUFFER_SIZE:
-                        grad_log(L_WARN,
+                        grad_log(GRAD_LOG_WARN,
 			         "%s:%d: %s",
 			         sqlfile, line_no,
 			         _("query_buffer_size is obsolete"));
@@ -439,7 +438,7 @@ radiusd_sql_config()
                 case STMT_INTERFACE:
                         new_cfg.interface = disp_sql_interface_index(cur_ptr);
                         if (!new_cfg.interface) {
-                                grad_log(L_WARN, "%s:%d: %s",
+                                grad_log(GRAD_LOG_WARN, "%s:%d: %s",
                                          sqlfile, line_no,
 				         _("Unsupported SQL interface"));
                         }
@@ -458,7 +457,7 @@ radiusd_sql_config()
         fclose(sqlfd);
 
         sql_check_config(sqlfile, &new_cfg);
-        grad_free(sqlfile);
+        free(sqlfile);
 
         if (!sql_cfg_empty_p(&sql_cfg)
 	    && sql_cfg_comp(&new_cfg, &sql_cfg)) 
@@ -480,14 +479,14 @@ radiusd_sql_config()
 }
 
 void
-radiusd_sql_clear_cache()
+radiusd_sql_clear_cache(void)
 {
 	sql_cache_destroy(sql_conn[SQL_AUTH]);
 	sql_cache_destroy(sql_conn[SQL_ACCT]);
 }
 
 void
-radiusd_sql_shutdown()
+radiusd_sql_shutdown(void)
 {
 	sql_conn_destroy(&sql_conn[SQL_AUTH]);
 	sql_conn_destroy(&sql_conn[SQL_ACCT]);
@@ -507,30 +506,30 @@ sql_check_config(const char *filename, SQL_cfg *cfg)
 	int doacct = cfg->active[SQL_ACCT];
 
 #define FREE_IF_EMPTY(s) if (s && strcmp(s, "none") == 0) {\
-                                grad_free(s);\
+                                free(s);\
                                 s = NULL;\
                          }
 
 	/* Check general SQL setup */
 	if (cfg->active[SQL_AUTH] || cfg->active[SQL_ACCT]) {
 		if (disp_sql_interface_index(NULL) == 0) {
-			grad_log(L_ERR, _("%s: SQL interface not specified"),
+			grad_log(GRAD_LOG_ERR, _("%s: SQL interface not specified"),
 				 filename);
 			doacct = doauth = 0;
 		}
 
 		if (!cfg->server) {
-			missing_statement(L_ERR, filename, "server");
+			missing_statement(GRAD_LOG_ERR, filename, "server");
 			doacct = doauth = 0;
 		}
 
 		if (!cfg->login) {
-			missing_statement(L_ERR, filename, "login");
+			missing_statement(GRAD_LOG_ERR, filename, "login");
 			doacct = doauth = 0;
 		}
 
 		if (!cfg->password) {
-			missing_statement(L_ERR, filename, "password");
+			missing_statement(GRAD_LOG_ERR, filename, "password");
 			doacct = doauth = 0;
 		}
 	}
@@ -538,60 +537,60 @@ sql_check_config(const char *filename, SQL_cfg *cfg)
 	/* Check SQL authentication setup */
         if (cfg->active[SQL_AUTH]) {
 		if (!cfg->auth_db) {
-			missing_statement(L_ERR, filename, "auth_db");
+			missing_statement(GRAD_LOG_ERR, filename, "auth_db");
 			doauth = 0;
 		}
 
 		FREE_IF_EMPTY(cfg->query[auth_query]);
 		if (!cfg->query[auth_query]) {
-			missing_statement(L_ERR, filename, "auth_query");
+			missing_statement(GRAD_LOG_ERR, filename, "auth_query");
 			doauth = 0;
 		}
 			 
 		if (!cfg->query[group_query]) 
-			missing_statement(L_WARN, filename, "group_query");
+			missing_statement(GRAD_LOG_WARN, filename, "group_query");
                 FREE_IF_EMPTY(cfg->query[group_query]);
         }
 
 	/* Check SQL accounting setup */
         if (cfg->active[SQL_ACCT]) {
 		if (!cfg->acct_db) {
-			missing_statement(L_ERR, filename, "acct_db");
+			missing_statement(GRAD_LOG_ERR, filename, "acct_db");
 			doacct = 0;
 		}
                 if (!cfg->query[acct_start_query]) 
-			missing_statement(L_WARN, filename,
+			missing_statement(GRAD_LOG_WARN, filename,
 					  "acct_start_query");
                 FREE_IF_EMPTY(cfg->query[acct_start_query]);
 
 		if (!cfg->query[acct_stop_query]) {
-			missing_statement(L_ERR, filename, "acct_stop_query");
+			missing_statement(GRAD_LOG_ERR, filename, "acct_stop_query");
 			doacct = 0;
 		}
 		FREE_IF_EMPTY(cfg->query[acct_stop_query]);
 
                 if (!cfg->query[acct_nasdown_query]) 
-			missing_statement(L_WARN, filename,
+			missing_statement(GRAD_LOG_WARN, filename,
 					  "acct_nasdown_query");
                 FREE_IF_EMPTY(cfg->query[acct_nasdown_query]);
 
                 if (!cfg->query[acct_nasup_query])
-			missing_statement(L_WARN, filename,
+			missing_statement(GRAD_LOG_WARN, filename,
 					  "acct_nasup_query");
                 FREE_IF_EMPTY(cfg->query[acct_nasup_query]);
         }
 
 	/* Inform the user */
 	if (cfg->active[SQL_AUTH] != doauth)
-		grad_log(L_NOTICE, _("disabling SQL authentication"));
+		grad_log(GRAD_LOG_NOTICE, _("disabling SQL authentication"));
 	if (cfg->active[SQL_ACCT] != doacct)
-		grad_log(L_NOTICE, _("disabling SQL accounting"));
+		grad_log(GRAD_LOG_NOTICE, _("disabling SQL accounting"));
 }
 
 void
-sql_flush()
+sql_flush(void)
 {
-        grad_log(L_NOTICE,
+        grad_log(GRAD_LOG_NOTICE,
                  _("SQL configuration changed: closing existing connections"));
         radiusd_flush_queue();
 	radiusd_sql_shutdown();
@@ -606,15 +605,15 @@ sql_result_destroy(SQL_RESULT *res)
 	
 	if (!res)
 		return;
-	grad_free(res->query);
+	free(res->query);
 	for (i = 0; i < res->ntuples; i++) {
 		size_t j;
 		for (j = 0; j < res->nfields; j++) 
-			grad_free(res->tuple[i][j]);
-		grad_free(res->tuple[i]);
+			free(res->tuple[i][j]);
+		free(res->tuple[i]);
 	}
-	grad_free(res->tuple);
-	grad_free(res);
+	free(res->tuple);
+	free(res);
 }
 
 static size_t
@@ -629,8 +628,6 @@ sql_cache_level(struct sql_connection *conn)
 static void
 sql_cache_destroy(struct sql_connection *conn)
 {
-	size_t i;
-
 	if (!conn)
 		return;
 	for (; sql_cache_level(conn) > 0;
@@ -680,12 +677,13 @@ sql_cache_retrieve(struct sql_connection *conn, char *query)
 		return res;
 	}
 
-	res->tuple = grad_emalloc(sizeof(res->tuple[0]) * res->ntuples);
+	res->tuple = grad_ecalloc(res->ntuples, sizeof(res->tuple[0]));
         for (i = 0; i < res->ntuples
 		     && disp_sql_next_tuple(conn, data) == 0; i++) {
 		int j;
 
-		res->tuple[i] = grad_emalloc(sizeof(res->tuple[0][0]) * res->nfields);
+		res->tuple[i] = grad_ecalloc(res->nfields,
+					     sizeof(res->tuple[0][0]));
 			
 		for (j = 0; j < res->nfields; j++) {
 			char *p = disp_sql_column(conn, data, j);
@@ -775,7 +773,7 @@ sql_conn_destroy(struct sql_connection **conn)
 	        if ((*conn)->connected)
 		        disp_sql_disconnect(*conn);
 		sql_cache_destroy(*conn);
-		grad_free(*conn);
+		free(*conn);
 		*conn = NULL;
 	}
 }
@@ -812,7 +810,7 @@ radiusd_sql_acct(radiusd_request_t *radreq)
         if (!(pair = grad_avl_find(radreq->request->avlist,
 				   DA_ACCT_STATUS_TYPE))) {
                 /* should never happen!! */
-                grad_log_req(L_ERR, radreq->request,
+                grad_log_req(GRAD_LOG_ERR, radreq->request,
                              _("no Acct-Status-Type attribute in rad_sql_acct()"));
                 return;
         }
@@ -844,7 +842,7 @@ radiusd_sql_acct(radiusd_request_t *radreq)
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
                 if (rc == 0 && count != 1) 
-			log_facility = L_WARN;
+			log_facility = GRAD_LOG_WARN;
                 break;
 
         case DV_ACCT_STATUS_TYPE_ACCOUNTING_ON:
@@ -857,7 +855,7 @@ radiusd_sql_acct(radiusd_request_t *radreq)
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
 		if (rc == 0)
-			log_facility = L_INFO;
+			log_facility = GRAD_LOG_INFO;
                 break;
 
         case DV_ACCT_STATUS_TYPE_ACCOUNTING_OFF:
@@ -870,7 +868,7 @@ radiusd_sql_acct(radiusd_request_t *radreq)
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
 		if (rc == 0)
-			log_facility = L_INFO;
+			log_facility = GRAD_LOG_INFO;
                 break;
 
         case DV_ACCT_STATUS_TYPE_ALIVE:
@@ -883,7 +881,7 @@ radiusd_sql_acct(radiusd_request_t *radreq)
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
                 if (rc == 0 && count != 1) 
-			log_facility = L_WARN;
+			log_facility = GRAD_LOG_WARN;
                 break;
                 
         }
@@ -910,7 +908,7 @@ radiusd_sql_pass(radiusd_request_t *req, char *authdata)
         struct obstack stack;
         
         if (sql_cfg.active[SQL_AUTH] == 0) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          _("SQL Auth specified in users file, but not in sqlserver file"));
                 return NULL;
         }
@@ -1009,7 +1007,7 @@ rad_sql_retrieve_pairs(struct sql_connection *conn,
 			char *opstr = res->tuple[i][2];
                         op = grad_str_to_op(opstr);
                         if (op == grad_operator_invalid) {
-                                grad_log(L_NOTICE,
+                                grad_log(GRAD_LOG_NOTICE,
                                          _("SQL: invalid operator: %s"), opstr);
                                 continue;
                         }
@@ -1123,8 +1121,6 @@ rad_sql_retrieve_sessions(struct sql_connection *conn,
 {
 	SQL_RESULT *res;
 	size_t i;
-	grad_locus_t loc;
-	struct radutmp utmp;
 	
 	res = sql_cache_lookup(conn, query);
 	if (!res) {
@@ -1172,7 +1168,7 @@ sql_mlc_collect(const char *query_template,
 }
 
 int
-rad_sql_mlc_enabled_p()
+rad_sql_mlc_enabled_p(void)
 {
 	return sql_cfg.active[SQL_ACCT]
 		&& sql_cfg.query[mlc_user_query];
@@ -1206,7 +1202,7 @@ rad_sql_mlc_close(struct radutmp *up)
 	struct obstack stack;
 	grad_request_t *req;
 	int rc;
-	size_t count;
+	int count;
 	struct sql_connection *conn;
 	
 	if (sql_cfg.active[SQL_ACCT] == 0 || !sql_cfg.query[query_index])
@@ -1220,6 +1216,9 @@ rad_sql_mlc_close(struct radutmp *up)
 	grad_avl_add_pair(&req->avlist,
 			  grad_avp_create_integer(DA_NAS_PORT_ID,
 						  up->nas_port));
+	grad_avl_add_pair(&req->avlist,
+			  grad_avp_create_integer(DA_NAS_IP_ADDRESS,
+						  ntohl(up->nas_address)));
 	grad_avl_add_pair(&req->avlist,
 			  grad_avp_create_string(DA_ACCT_SESSION_ID,
 						 up->session_id));
@@ -1228,7 +1227,7 @@ rad_sql_mlc_close(struct radutmp *up)
 	rc = disp_sql_query(conn, query, &count);
 	sqllog(rc, query);
 	if (rc == 0 && count != 1) {
-		grad_log(L_WARN,
+		grad_log(GRAD_LOG_WARN,
 			 ngettext("%s updated %d record",
 				  "%s updated %d records",
 				  count),
@@ -1240,7 +1239,7 @@ rad_sql_mlc_close(struct radutmp *up)
 
 
 void
-sql_init()
+sql_init(void)
 {
 	mlc_register_method("sql",
 			    rad_sql_mlc_collect_user,
@@ -1257,7 +1256,7 @@ sql_init()
 #ifdef USE_SERVER_GUILE
 
 SCM
-sql_exec_query(int type, char *query)
+sql_exec_query(int type, const char *query)
 {
 	int i, j;
         struct sql_connection *conn;
@@ -1276,42 +1275,33 @@ sql_exec_query(int type, char *query)
 		SCM new_row;
 		SCM head = SCM_EOL, tail;
 		
-		for (j = 0; tuple = disp_sql_column(conn, data, j); j++) {
-			SCM new_elt;
-			SCM_NEWCELL(new_elt);
-			SCM_SETCAR(new_elt, scm_makfrom0str(tuple));
+		for (j = 0; (tuple = disp_sql_column(conn, data, j)); j++) {
+			SCM new_elt = scm_cons(scm_from_locale_string(tuple),
+					       SCM_EOL);
 			if (head == SCM_EOL)
 				head = new_elt;
 			else
 				SCM_SETCDR(tail, new_elt);
 			tail = new_elt;
 		}
-		if (head != SCM_EOL)
-			SCM_SETCDR(tail, SCM_EOL);
-		SCM_NEWCELL(new_row);
-		SCM_SETCAR(new_row, head);
-
+		new_row = scm_cons(head, SCM_EOL);
 		if (row_head == SCM_EOL)
 			row_head = new_row;
 		else
 			SCM_SETCDR(row_tail, new_row);
 		row_tail = new_row;
 	}
-	if (row_head != SCM_EOL)
-		SCM_SETCDR(row_tail, SCM_EOL);
-
 	disp_sql_free(conn, data);
 	
 	return row_head;
 }
 
 SCM
-sql_run_query(int type, char *query)
+sql_run_query(int type, const char *query)
 {
 	int rc;
         struct sql_connection *conn;
 	int count;
-	SCM res;
 	
 	if (type < 0 || type > SQL_NSERVICE)
 		return SCM_BOOL_F;
@@ -1319,7 +1309,7 @@ sql_run_query(int type, char *query)
 	rc = disp_sql_query(conn, query, &count);
 	if (rc)
                 return SCM_BOOL_F;
-	return scm_long2num(count);
+	return scm_from_long(count);
 }
 #endif
 
