@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2003,2004,2005,2007,2008 Free Software Foundation
+   Copyright (C) 2003-2025 Free Software Foundation
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -46,8 +45,6 @@ static grad_request_t test_req;
 static char *tsh_ps1 = "(radiusd) ";
 static char *tsh_ps2 = "[radiusd] ";
 
-static char *tsh_readline(const char *prompt);
-
 static void tsh_help(int argc, char **argv, char *cmd);
 static void tsh_query_nas(int argc, char **argv, char *cmd);
 #ifdef USE_SERVER_GUILE
@@ -141,8 +138,6 @@ tsh_help(int argc, char **argv, char *cmd ARG_UNUSED)
 	int n;
 	
 	for (cp = command_table; cp->shortname; cp++) {
-		int len = strlen(cp->shortname);
-
 		n = printf("%-8.8s%s", cp->shortname, cp->longname);
 		if (cp->usage)
 			n += printf(" %s", cp->usage);
@@ -274,7 +269,6 @@ tsh_timespan(int argc, char **argv, char *cmd ARG_UNUSED)
         TIMESPAN       *ts;
         char           *p;
         unsigned       rest;
-        int i;
         struct tm tm;
 	int diff, dow;
 	
@@ -412,7 +406,7 @@ tsh_command_generator(const char *text, int state)
  * readline tab completion
  */
 static char **
-tsh_command_completion(char *cmd, int start ARG_UNUSED, int end ARG_UNUSED)
+tsh_command_completion(char const *cmd, int start ARG_UNUSED, int end ARG_UNUSED)
 {
 	if (start == 0)
 		return rl_completion_matches(cmd, tsh_command_generator);
@@ -481,8 +475,8 @@ tsh_run_command(char *cmd)
 	grad_argcv_free(argc, argv);
 }
 
-int
-tsh()
+void
+tsh(void)
 {
 	char *cmd;
 
