@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -15,10 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
-
-/* $Id$ */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -67,8 +63,8 @@ static char *sys_def[] = {
 };
 
 static char *debug_flag_str[] = {
-#if defined(MAINTAINER_MODE)
-        "MAINTAINER_MODE",
+#if defined(EXTRA_DEBUG_MODE)
+        "EXTRA_DEBUG_MODE",
 #endif
         NULL
 };
@@ -133,7 +129,7 @@ char *server_id;
  *  %h - hostname
  */
 char *
-make_server_ident()
+make_server_ident(void)
 {
         if (server_id)
                 return grad_estrdup(server_id);
@@ -177,8 +173,8 @@ version(FILE *stream, struct argp_state *state)
         fprintf(stream, "\n");
 	fprintf(stream, _("Compilation defaults:\n"));
         fprintf(stream, _("Ports in use:\n"));
-        fprintf(stream, " AUTH: %d\n", DEF_AUTH_PORT);
-        fprintf(stream, " ACCT: %d\n", DEF_ACCT_PORT);
+        fprintf(stream, " AUTH: %d\n", RADIUS_AUTH_PORT);
+        fprintf(stream, " ACCT: %d\n", RADIUS_ACCT_PORT);
         fprintf(stream, _("Paths:\n"));
         fprintf(stream, _(" configuration directory: %s\n"), RADIUS_DIR);
         fprintf(stream, _(" logging directory:       %s\n"), RADLOG_DIR);
@@ -189,7 +185,7 @@ version(FILE *stream, struct argp_state *state)
 }
 
 void
-show_compilation_defaults()
+show_compilation_defaults(void)
 {
 	int i;
 	
