@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2002,2003,2004,2005,2007,
-   2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -73,7 +71,7 @@ WTMP *find_wtmp_nas(WTMP *first, struct radutmp *bp);
 WTMP *find_wtmp_nas_port(WTMP *first, struct radutmp *bp);
 WTMP *find_wtmp_nas_port_sid(WTMP *first, struct radutmp *bp);
 
-grad_uint32_t host_ip = 0;
+uint32_t host_ip = 0;
 grad_netdef_t nas_ip = { 0, 0 } ;
 int port = 0;
 int width = 5;
@@ -261,24 +259,24 @@ main(int argc, char **argv)
 }
 
 int
-read_naslist()
+read_naslist(void)
 {
         int rc;
         char *path = grad_mkfilename(grad_config_dir, RADIUS_NASLIST);
         rc = grad_nas_read_file(path);
-        grad_free(path);
+        free(path);
         return rc;
 }
 
 #if 0
 int
-rawread()
+rawread(void)
 {
         int wfd;
         struct radutmp ut;
         struct tm *tm;
         char ct[256];
-        grad_uint32_t ipaddr;
+        uint32_t ipaddr;
         char ip_str[GRAD_IPV4_STRING_LENGTH];
         
         if ((wfd = open(file, O_RDONLY, 0)) < 0) {
@@ -326,14 +324,14 @@ rawread()
 
 volatile int stop;
 
-RETSIGTYPE
+void
 sig_int(int sig)
 {
         stop = 1;
 }
 
 void
-radwtmp()
+radwtmp(void)
 {
         int wfd;
         struct stat stb;
@@ -365,20 +363,20 @@ radwtmp()
 		     --bp) {
                         switch (bp->type) {
                         case P_LOGIN:
-                                if (pp = find_logout(bp)) {
+                                if ((pp = find_logout(bp)) != NULL) {
                                         if (want(bp)) {
                                                 print_entry(pp, bp, 0);
                                                 if (maxrec != -1 && !--maxrec)
                                                         return;
                                         }
                                         delete_logout(pp, bp);
-                                } else if (pp = find_restart(bp)) {
+                                } else if ((pp = find_restart(bp)) != NULL) {
                                         if (want(bp)) {
                                                 print_entry(pp, bp, 0);
                                                 if (maxrec != -1 && !--maxrec)
                                                         return;
                                         }
-                                } else if (pp = find_login(bp)) {
+                                } else if ((pp = find_login(bp)) != NULL) {
                                         /* Ignore duplicate logins */
                                         if (strncmp(pp->ut.session_id,
                                                    bp->session_id,
@@ -540,9 +538,9 @@ delete_wtmp_entry(WTMP **first, WTMP *pp)
 
         if (pp == *first) 
                 *first = (*first)->next;
-        if (p = pp->prev) 
+        if ((p = pp->prev) != NULL)
                 p->next = pp->next;
-        if (p = pp->next)
+        if ((p = pp->next) != NULL)
                 p->prev = pp->prev;
         return pp;
 }
@@ -597,9 +595,9 @@ add_logout(struct radutmp *bp)
         wp->ut = *bp;
         add_wtmp_entry(&logout_list, wp);
         /* purge deleted queue */
-        if (wp = find_wtmp_nas_port(login_list, bp)) {
+        if ((wp = find_wtmp_nas_port(login_list, bp)) != NULL) {
                 delete_wtmp_entry(&login_list, wp);
-                grad_free(wp);
+                free(wp);
         }
 }
 
@@ -608,9 +606,9 @@ add_nas_restart(struct radutmp *bp)
 {
         WTMP *wp;
 
-        if (wp = find_wtmp_nas(nas_updown_list, bp)) {
+        if ((wp = find_wtmp_nas(nas_updown_list, bp)) != NULL) {
                 delete_wtmp_entry(&nas_updown_list, wp);
-                grad_free(wp);
+                free(wp);
         }
                     
         wp = grad_emalloc(sizeof(*wp));
@@ -697,7 +695,7 @@ print_entry(WTMP *pp, struct radutmp *bp, int mark)
         char ct[256];
         char ip_str[IP_ADDR_LEN+1];
         time_t delta;
-        grad_uint32_t ipaddr;
+        uint32_t ipaddr;
         char buf[GRAD_MAX_LONGNAME];
         
         tm = localtime(&bp->time);
