@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2007,
-   2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -24,6 +22,7 @@
 
 #include <libguile.h>
 #include <radius/radius.h>
+#include <radiusd.h>
 #include <radius/radscm.h>
 
 static grad_keyword_t radlog_kw[] = {
@@ -51,74 +50,70 @@ static int
 parse_facility(SCM list)
 {
         int accval = 0;
-        for (; list != SCM_EOL; list = SCM_CDR(list)) {
+        for (; !scm_is_null(list); list = SCM_CDR(list)) {
                 SCM car = SCM_CAR(list);
                 int val = 0;
                 
                 if (scm_is_integer(car)) 
                         val = scm_to_int(car);
-                else if (scm_is_string(car))
-                        val = grad_xlat_keyword(radlog_kw,
-						scm_i_string_chars(car), 0);
-                else if (SCM_BIGP(car)) 
-		  val = (grad_uint32_t) scm_i_big2dbl(car);
-                else
-                        continue;
+                else if (scm_is_string(car)) {
+			char *s = scm_to_locale_string(car);
+                        val = grad_xlat_keyword(radlog_kw, s, 0);
+			free(s);
+		} else
+                        continue; /* FIXME: warning message? */
                 accval |= val;
         } 
         return accval;
 }
 
-SCM_DEFINE(rad_log_open, "rad-log-open", 1, 0, 0,
-           (SCM PRIO),
-"Open radius logging to the severity level PRIO.")         
+SCM_DEFINE_PUBLIC(rad_log_open, "rad-log-open", 1, 0, 0,
+		  (SCM prio),
+"Opens logging to radius severity level @var{prio}.")         
 #define FUNC_NAME s_rad_log_open
 {
-        int prio;
+        int n_prio;
 
-        if (scm_is_integer(PRIO)) {
-                prio = scm_to_int(PRIO);
-        } else if (SCM_BIGP(PRIO)) {
-                prio = (grad_uint32_t) scm_i_big2dbl(PRIO);
+        if (scm_is_integer(prio)) {
+                n_prio = scm_to_int(prio);
         } else {
-                SCM_ASSERT(SCM_NIMP(PRIO) && SCM_CONSP(PRIO),
-                           PRIO, SCM_ARG1, FUNC_NAME);
-                prio = parse_facility(PRIO);
+                SCM_ASSERT(scm_is_pair(prio), prio, SCM_ARG1, FUNC_NAME);
+                n_prio = parse_facility(prio);
         }
 
-        log_open(prio);
+        log_open(n_prio);
         return SCM_UNSPECIFIED;
 }
 #undef FUNC_NAME
 
-SCM_DEFINE(rad_log, "rad-log", 2, 0, 0,
-           (SCM PRIO, SCM TEXT),
-"Output TEXT to the radius logging channel corresponding to\n"
-"category/severity given by PRIO.\n")
+SCM_DEFINE_PUBLIC(rad_log, "rad-log", 2, 0, 0,
+		  (SCM prio, SCM text),
+"Outputs @var{text} to the radius logging channel corresponding to "
+"category/severity given by @var{prio}.\n")
 #define FUNC_NAME s_rad_log
 {
-        int prio;
-        if (PRIO == SCM_BOOL_F) {
-                prio = GRAD_LOG_INFO;
-        } else if (scm_is_integer(PRIO)) {
-                prio = scm_to_int(PRIO);
-        } else if (SCM_BIGP(PRIO)) {
-                prio = (grad_uint32_t) scm_i_big2dbl(PRIO);
+        int n_prio;
+	char *s;
+	
+	if (scm_is_integer(prio)) {
+                n_prio = scm_to_int(prio);
         } else {
-                SCM_ASSERT(SCM_NIMP(PRIO) && SCM_CONSP(PRIO),
-                           PRIO, SCM_ARG1, FUNC_NAME);
-                prio = parse_facility(PRIO);
+                SCM_ASSERT(scm_is_pair(prio), prio, SCM_ARG1, FUNC_NAME);
+                n_prio = parse_facility(prio);
         }
 
-        SCM_ASSERT(scm_is_string(TEXT), TEXT, SCM_ARG1, FUNC_NAME);
-        grad_log(prio, "%s", scm_i_string_chars(TEXT));
+        SCM_ASSERT(scm_is_string(text), text, SCM_ARG2, FUNC_NAME);
+	s = scm_to_locale_string(text);
+        grad_log(n_prio, "%s", s);
+	free(s);
         return SCM_UNSPECIFIED;
 }
 #undef FUNC_NAME
 
-SCM_DEFINE(rad_log_close, "rad-log-close", 0, 0, 0,
-           (),
-"Close radius logging channel open by a previous call to rad-log-open.\n")
+SCM_DEFINE_PUBLIC(rad_log_close, "rad-log-close", 0, 0, 0,
+		  (),
+"Closes a radius logging channel open by a previous call to "
+"@code{rad-log-open}.\n")
 #define FUNC_NAME s_rad_log_close
 {
         log_close();
@@ -127,11 +122,13 @@ SCM_DEFINE(rad_log_close, "rad-log-close", 0, 0, 0,
 #undef FUNC_NAME
 
 void
-rscm_radlog_init()
+rscm_radlog_init(void)
 {
         int i;
-        for (i = 0; radlog_kw[i].name; i++)
+        for (i = 0; radlog_kw[i].name; i++) {
                 scm_c_define(radlog_kw[i].name,
                              scm_from_int(radlog_kw[i].tok));
+		scm_c_export (radlog_kw[i].name, NULL);
+	}
 #include <rscm_radlog.x>
 }
