@@ -1,11 +1,12 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2005 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software
+   Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -14,8 +15,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -27,23 +27,28 @@
 #include <rewrite.h>
 #include <radius/radscm.h>
 
-SCM_DEFINE(rad_rewrite_execute_string, "rad-rewrite-execute-string", 1, 0, 0,
-           (SCM STRING),
-"Interpret STRING as an invocation of a function in Rewrite language and\n"
-"execute it.\n"
-"Return value: return of the corresponding Rewrite call, translated to\n"
-"the Scheme data type.\n")         
+SCM_DEFINE_PUBLIC(rad_rewrite_execute_string, "rad-rewrite-execute-string",
+		  1, 0, 0,
+		  (SCM string),
+"Interprets @var{string} as a function call in Rewrite language and"
+"executes it.\n\n"
+"Return value: return of the corresponding Rewrite call, translated to "
+"a corresponding Scheme data type.\n")         
 #define FUNC_NAME s_rad_rewrite_execute_string
 {
 	grad_value_t val;
 	SCM retval;
+	char *str;
+	int rc;
 	
-        SCM_ASSERT(SCM_NIMP(STRING) && SCM_STRINGP(STRING),
-                   STRING, SCM_ARG1, FUNC_NAME);
-        if (rewrite_interpret(SCM_STRING_CHARS(STRING), NULL, &val)) {
+        SCM_ASSERT(scm_is_string(string), string, SCM_ARG1, FUNC_NAME);
+	str = scm_to_locale_string(string);
+	rc = rewrite_interpret(str, NULL, &val);
+	free(str);
+        if (rc) {
                 scm_misc_error(FUNC_NAME,
                                "Error parsing expression: ~S",
-                               scm_list_1(STRING));
+                               scm_list_1(string));
         }
 
         retval = radscm_datum_to_scm(&val);
@@ -52,31 +57,30 @@ SCM_DEFINE(rad_rewrite_execute_string, "rad-rewrite-execute-string", 1, 0, 0,
 }
 #undef FUNC_NAME
 
-SCM_DEFINE(rad_rewrite_execute, "rad-rewrite-execute", 1, 0, 0,
-           (SCM ARGLIST),
-"Execute a Rewrite language function.\n"
-"(car ARGLIST) is interpreted as a name of the Rewrite function to execute,\n"
-"and (cdr ARGLIST) as a list of arguments to be passed to it.\n"
+SCM_DEFINE_PUBLIC(rad_rewrite_execute, "rad-rewrite-execute", 1, 0, 0,
+		  (SCM arglist),
+"Executes a Rewrite language function.\n"
+"@code{(car @var{arglist})} is interpreted as a name of function to run, "
+"and @code{(cdr @var{arglist})} as a list of arguments to be passed to it.\n\n"
 "Return value: return of the corresponding Rewrite call, translated to\n"
-"the Scheme data type.\n")         
+"a corresponding Scheme data type.\n")         
 #define FUNC_NAME s_rad_rewrite_execute
 {
-        SCM_ASSERT((SCM_IMP(ARGLIST) && ARGLIST == SCM_EOL)
-                   || (SCM_NIMP(ARGLIST) && SCM_CONSP(ARGLIST)),
-                   ARGLIST, SCM_ARG2, FUNC_NAME);
+        SCM_ASSERT(scm_is_null(arglist) || scm_is_pair(arglist),
+                   arglist, SCM_ARG1, FUNC_NAME);
         
-        return radscm_rewrite_execute(FUNC_NAME, ARGLIST);
+        return radscm_rewrite_execute(FUNC_NAME, arglist);
 }
 #undef FUNC_NAME
 
 void
-rscm_rewrite_init()
+rscm_rewrite_init(void)
 {
 #include <rscm_rewrite.x>
 }
 
 void
-rscm_server_init()
+rscm_server_init(void)
 {
 	rscm_radlog_init();
 	rscm_rewrite_init();
