@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -59,99 +58,97 @@ parse_facility(SCM list)
 {
         int accval = 0;
         
-        for (; list != SCM_EOL; list = SCM_CDR(list)) {
+        for (; !scm_is_null(list); list = SCM_CDR(list)) {
                 SCM car = SCM_CAR(list);
                 int val = 0;
                 
                 if (scm_is_integer(car)) 
                         val = scm_to_int(car);
-                else if (scm_is_string(car))
-                        val = grad_xlat_keyword(syslog_kw,
-						scm_i_string_chars(car), 0);
-                else
-                        continue;
+                else if (scm_is_string(car)) {
+			char *s = scm_to_locale_string(car);
+                        val = grad_xlat_keyword(syslog_kw, s, 0);
+			free(s);
+		} else
+                        continue; /* FIXME: warning message */
                 accval |= val;
         } 
         return accval;
 }
 
-SCM_DEFINE(rad_openlog, "rad-openlog", 3, 0, 0,
-           (SCM IDENT, SCM OPTION, SCM FACILITY),
-"Scheme interface to the system openlog() call.")          
+static char *log_tag;
+
+SCM_DEFINE_PUBLIC(rad_openlog, "rad-openlog", 3, 0, 0,
+		  (SCM ident, SCM option, SCM facility),
+"Opens a connection to the system logger. "
+"The arguments @var{ident}, @var{option} and @var{facility} have the same "
+"meaning as in openlog(3).\n")
 #define FUNC_NAME s_rad_openlog
 {
-        const char *ident;
-        int option, facility;
+        int opt, facl;
 
-        if (IDENT == SCM_BOOL_F)
-                ident = "radius";
-        else {
-                SCM_ASSERT(scm_is_string(IDENT), IDENT, SCM_ARG1, FUNC_NAME);
-                ident = scm_i_string_chars(IDENT);
-        }
+	if (log_tag)
+		free(log_tag);
+	SCM_ASSERT(scm_is_string(ident), ident, SCM_ARG1, FUNC_NAME);
+	log_tag = scm_to_locale_string(ident);
         
-        if (scm_is_integer(OPTION)) {
-                option = scm_to_int(OPTION);
-        } else if (SCM_BIGP(OPTION)) {
-                option = (grad_uint32_t) scm_i_big2dbl(OPTION);
+        if (scm_is_integer(option)) {
+                opt = scm_to_int(option);
         } else {
-                SCM_ASSERT(SCM_NIMP(OPTION) && SCM_CONSP(OPTION),
-                           OPTION, SCM_ARG2, FUNC_NAME);
-                option = parse_facility(OPTION);
+                SCM_ASSERT(scm_is_pair(option), option, SCM_ARG2, FUNC_NAME);
+                opt = parse_facility(option);
         }
 
-        if (scm_is_integer(FACILITY)) {
-                facility = scm_to_int(FACILITY);
-        } else if (SCM_BIGP(FACILITY)) {
-                facility = (grad_uint32_t) scm_i_big2dbl(FACILITY);
+        if (scm_is_integer(facility)) {
+                facl = scm_to_int(facility);
         } else {
-                SCM_ASSERT(SCM_NIMP(FACILITY) && SCM_CONSP(FACILITY),
-                           FACILITY, SCM_ARG3, FUNC_NAME);
-                facility = parse_facility(FACILITY);
+                SCM_ASSERT(scm_is_pair(facility),
+			   facility, SCM_ARG3, FUNC_NAME);
+                facl = parse_facility(facility);
         }
 
-        openlog(ident, option, facility);
+        openlog(log_tag, opt, facl);
         return SCM_UNSPECIFIED;
 }
 #undef FUNC_NAME
 
-SCM_DEFINE(rad_syslog, "rad-syslog", 2, 0, 0,
-           (SCM PRIO, SCM TEXT),
-"Scheme interface to the system syslog() call.")           
+SCM_DEFINE_PUBLIC(rad_syslog, "rad-syslog", 2, 0, 0,
+		  (SCM prio, SCM text),
+"Distributes @var{text} via syslogd priority @var{prio}.\n")
 #define FUNC_NAME s_rad_syslog
 {
-        int prio;
-
-        if (PRIO == SCM_BOOL_F) {
-                prio = LOG_INFO;
-        } else if (scm_is_integer(PRIO)) {
-                prio = scm_to_int(PRIO);
-        } else if (SCM_BIGP(PRIO)) {
-                prio = (grad_uint32_t) scm_i_big2dbl(PRIO);
-        } else {
-                SCM_ASSERT(SCM_NIMP(PRIO) && SCM_CONSP(PRIO),
-                           PRIO, SCM_ARG1, FUNC_NAME);
-                prio = parse_facility(PRIO);
+        int n_prio;
+	char *s;
+	
+	if (scm_is_integer(prio)) {
+                n_prio = scm_to_int(prio);
+	} else {
+		SCM_ASSERT(scm_is_pair(prio), prio, SCM_ARG1, FUNC_NAME);
+                n_prio = parse_facility(prio);
         }
 
-        SCM_ASSERT(scm_is_string(TEXT), TEXT, SCM_ARG1, FUNC_NAME);
-        syslog(prio, "%s", scm_i_string_chars(TEXT));
+        SCM_ASSERT(scm_is_string(text), text, SCM_ARG2, FUNC_NAME);
+	s = scm_to_locale_string(text);
+        syslog(n_prio, "%s", s);
+	free(s);
         return SCM_UNSPECIFIED;
 }
 #undef FUNC_NAME
 
-SCM_DEFINE(rad_closelog, "rad-closelog", 0, 0, 0,
-           (),
-"Scheme interface to the system closelog() call.")         
+SCM_DEFINE_PUBLIC(rad_closelog, "rad-closelog", 0, 0, 0,
+		  (),
+"Closes the channel to the system logger opened by a previous call to "
+"@code{openlog}.\n")
 #define FUNC_NAME s_rad_closelog
 {
         closelog();
+	free(log_tag);
+	log_tag = NULL;
         return SCM_UNSPECIFIED;
 }
 #undef FUNC_NAME
 
 void
-rscm_syslog_init()
+rscm_syslog_init(void)
 {
         int i;
         for (i = 0; syslog_kw[i].name; i++)
