@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
@@ -13,10 +12,9 @@
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
- 
+
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #if defined(HAVE_CONFIG_H)        
 # include <config.h>
@@ -183,7 +181,7 @@ grad_avp_t *reply_list;         /* Last radius reply pairs */
 grad_list_t *toplevel_env;      /* Top level environment */
 
 static void
-init_symbols()
+init_symbols(void)
 {
         radtest_variable_t *var;
         
@@ -302,9 +300,9 @@ main(int argc, char **argv)
                 }
 
                 if (argc < 4)
-                        serv.port[0] = DEF_AUTH_PORT;
+                        serv.port[0] = RADIUS_AUTH_PORT;
                 if (argc < 6)
-                        serv.port[1] = DEF_ACCT_PORT;
+                        serv.port[1] = RADIUS_ACCT_PORT;
 		grad_client_append_server(srv_queue,
 					  grad_client_alloc_server(&serv));
                 grad_argcv_free(argc, argv);
@@ -423,7 +421,7 @@ var_print(radtest_variable_t *var)
 					  var->datum.bstring.ptr,
 					  var->datum.bstring.length);
 		printf("%s", pbuf);
-		grad_free(pbuf);
+		free(pbuf);
 	}
 		break;
 		       
@@ -442,12 +440,13 @@ var_print(radtest_variable_t *var)
         }
 }
 
-int
-var_free(radtest_variable_t *var)
+void
+var_free(void *p)
 {
+	radtest_variable_t *var = p;
         switch (var->type) {
         case rtv_string:
-                grad_free(var->datum.string);
+                free(var->datum.string);
                 break;
 		
         case rtv_avl:
@@ -457,7 +456,6 @@ var_free(radtest_variable_t *var)
 	default:
 		break;
         }
-	return 0;
 }
 
 void
