@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #if defined(HAVE_CONFIG_H)
 # include <config.h>
@@ -252,11 +250,11 @@ main(int  argc, char **argv)
         path = grad_mkfilename(grad_config_dir, RADIUS_NASLIST);
 	if (grad_nas_read_file(path))
                 exit(1);
-        grad_free(path);
+        free(path);
         /* Read realms */
         path = grad_mkfilename(grad_config_dir, RADIUS_REALMS);
 	grad_read_realms(path, 0, 0, NULL);
-        grad_free(path);
+        free(path);
         
         /*
          *      See if we are "fingerd".
@@ -313,7 +311,7 @@ tty_to_port(struct radutmp *rt, char *tty)
 }
 
 void
-local_who()
+local_who(void)
 {
         FILE  *fp;
         struct utmp ut;
@@ -354,7 +352,7 @@ local_who()
 }
 
 void
-radius_who()
+radius_who(void)
 {
         radut_file_t file;
         struct radutmp *up;
@@ -367,7 +365,7 @@ radius_who()
         if ((file = grad_ut_setent(filename, 0)) == NULL)
                 return ;
 
-        while (up = grad_ut_getent(file)) {
+        while ((up = grad_ut_getent(file)) != NULL) {
 		if (up->type == P_ACCT_DISABLED) 
 			printf(_("System accounting is disabled\n"));
 		else if (want_rad_record(up)) 
@@ -377,7 +375,7 @@ radius_who()
 }
 
 void
-print_header()
+print_header(void)
 {
         if (display_header) {
                 grad_utent_print_header(form);
