@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -96,7 +95,7 @@ parse_opt(int key, char *arg, struct argp_state *state)
                 break;
         case ARGP_KEY_FINI:
                 if (!args->user && !args->nas && args->port == -1) {
-                        grad_log(L_ERR,
+                        grad_log(GRAD_LOG_ERR,
                                  _("at least one port, nas or user must be specified"));
                         exit(1);
                 }
@@ -116,6 +115,8 @@ static struct argp argp = {
         NULL, NULL
 };
 
+static int confirm(struct radutmp *);
+static int write_wtmp(struct radutmp *);
 
 /*
  *      Zap a user, or all users on a NAS, from the radutmp file.
@@ -125,19 +126,19 @@ radzap(grad_netdef_t *netdef, int port, char *user, time_t t)
 {
         struct radutmp  *up;
         radut_file_t    file;
-        grad_uint32_t   netaddr;
 
         if (t == 0) 
                 time(&t);
 
         if ((file = grad_ut_setent(grad_utmp_file, 0)) == NULL) {
-                grad_log(L_ERR|L_PERROR, "can't open %s", grad_utmp_file);
+                grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR, 
+                         _("can't open file %s"), grad_utmp_file);
                 exit(1);
         }       
         /*
          *      Find the entry for this NAS / portno combination.
          */
-        while (up = grad_ut_getent(file)) {
+        while ((up = grad_ut_getent(file)) != NULL) {
                 if ((netdef
 		     && !grad_ip_in_net_p(netdef, htonl(up->nas_address)))
 		    || (port >= 0 && port != up->nas_port)
@@ -158,14 +159,14 @@ radzap(grad_netdef_t *netdef, int port, char *user, time_t t)
         return 0;
 }
 
-int
+static int
 confirm(struct radutmp *utp)
 {
         char buf[GRAD_MAX_LONGNAME];
         grad_nas_t *cl;
         char *s = NULL;
         
-        if (cl = grad_nas_lookup_ip(ntohl(utp->nas_address)))
+        if ((cl = grad_nas_lookup_ip(ntohl(utp->nas_address))) != NULL)
                 s = cl->shortname;
         if (s == NULL || s[0] == 0) 
                 s = grad_ip_gethostname(ntohl(utp->nas_address),
@@ -188,7 +189,7 @@ confirm(struct radutmp *utp)
         return 1;
 }
 
-int
+static int
 write_wtmp(struct radutmp *ut)
 {
         return grad_radwtmp_putent(grad_wtmp_file, ut);
@@ -208,7 +209,7 @@ main(int argc, char **argv)
         
         grad_app_setup();
 
-        if (s = getenv("RADZAP_CONFIRM"))
+        if ((s = getenv("RADZAP_CONFIRM")) != NULL)
                 confirm_flag = atoi(s);
 	args.radutmp = NULL;
         args.user = NULL;
@@ -225,7 +226,7 @@ main(int argc, char **argv)
         path = grad_mkfilename(grad_config_dir, RADIUS_NASLIST);
         if (grad_nas_read_file(path) < 0)
                 exit(1);
-        grad_free(path);
+        free(path);
 
         if (args.nas) {
                 grad_nas_t *np;
