@@ -1,6 +1,6 @@
 /*
    This file is part of GNU Radius SNMP Library.
-   Copyright (C) 2001,2003,2004,2007 Free Software Foundation, Inc.
+   Copyright (C) 2001-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -14,10 +14,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -59,7 +57,7 @@ snmp_pdu_add_var(struct snmp_pdu *pdu, struct snmp_var *var)
 }
 
 u_char *
-snmp_pdu_decode(u_char *data, int *length, struct snmp_pdu *pdu)
+snmp_pdu_decode(u_char *data, u_int *length, struct snmp_pdu *pdu)
 {
         u_char *buf = data;
         u_char type;
@@ -95,7 +93,7 @@ snmp_pdu_decode(u_char *data, int *length, struct snmp_pdu *pdu)
                 
                 
 u_char *
-snmp_pdu_encode(u_char *data, int *length, struct snmp_pdu *pdu)
+snmp_pdu_encode(u_char *data, u_int *length, struct snmp_pdu *pdu)
 {
         u_char *buf = data;
 
