@@ -1,6 +1,6 @@
 /*
    This file is part of GNU Radius SNMP Library.
-   Copyright (C) 2001,2003,2004,2007 Free Software Foundation, Inc.
+   Copyright (C) 2001-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -14,10 +14,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -60,13 +58,13 @@ snmp_errno_destroy(void *ptr)
 }
 
 static void
-snmp_errno_create()
+snmp_errno_create(void)
 {
         pthread_key_create(&snmp_errno_key, snmp_errno_destroy);
 }
 
 int *
-__snmp_errno_location()
+__snmp_errno_location(void)
 {
         int *p;
         pthread_once(&snmp_errno_once, snmp_errno_create);
@@ -84,14 +82,14 @@ __snmp_errno_location()
 static int __snmp_errno;
 
 int *
-__snmp_errno_location()
+__snmp_errno_location(void)
 {
 	return &__snmp_errno;
 }
 #endif
 
 int
-snmp_req_id()
+snmp_req_id(void)
 {
         if (snmp_def.req_id == 0) {
                 srand(time(NULL));
@@ -207,7 +205,7 @@ snmp_session_open(struct snmp_session *sp, ip_addr_t local_ip,
 #endif /* SO_BSDCOMPAT */
 
         addr = inet_addr(sp->remote_host);
-        if (addr = (ip_addr_t)-1) {
+        if (addr == (ip_addr_t)-1) {
                 struct hostent *hp = gethostbyname(sp->remote_host);
                 if (!hp) {
                         SNMP_SET_ERRNO(E_SNMP_BAD_ADDRESS);
