@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,
-   2006,2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -109,7 +107,7 @@ rad_mysql_reconnect(int type, struct sql_connection *conn)
 		         conn->cfg->server,
 		         conn->cfg->login,
 		         mysql_error((MYSQL*)conn->data));
-		grad_free(conn->data);
+		free(conn->data);
 		conn->data = NULL;
 		conn->connected = 0;
 		return -1;
@@ -124,7 +122,7 @@ static void
 rad_mysql_disconnect(struct sql_connection *conn, int drop ARG_UNUSED)
 {
 	mysql_close(conn->data);
-        grad_free(conn->data);
+        free(conn->data);
 	conn->data = NULL;  
         conn->connected = 0;
 }
@@ -269,7 +267,7 @@ rad_mysql_free(struct sql_connection *conn, void *data)
                 return;
 
         mysql_free_result(dp->result);
-        grad_free(dp);
+        free(dp);
 }
 
 DECL_SQL_DISPATCH_TAB(mysql) = {
