@@ -1,10 +1,10 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2001 Vlad Lungu
-   Copyright (C) 2000,2001,2004,2006,2007 Sergey Pozniakoff  
+   Copyright (C) 2000,2001,2004,2006,2007,2008 Sergey Pozniakoff  
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*/
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -52,7 +51,7 @@ rad_odbc_diag(SQLSMALLINT handle_type, SQLHANDLE handle, char *what)
                       state,
                       &nerror,
                       message, sizeof message, &msglen);
-        grad_log(L_ERR,
+        grad_log(GRAD_LOG_ERR,
                  "%s: %s %d %s",
                  what, state, nerror, message);
 }
@@ -130,13 +129,14 @@ rad_odbc_disconnect(struct sql_connection *conn, int drop ARG_UNUSED)
         odata = (ODBCconn*)(conn->data);        
         SQLDisconnect(odata->dbc);
         SQLFreeHandle(SQL_HANDLE_ENV, odata->env);
-        grad_free(conn->data);
+        free(conn->data);
         conn->data = NULL;
         conn->connected = 0;
 }
 
 static int
-rad_odbc_query(struct sql_connection *conn, char *query, int *return_count)
+rad_odbc_query(struct sql_connection *conn, const char *query,
+	       int *return_count)
 {
         ODBCconn        *odata;
         long            result;
@@ -176,7 +176,7 @@ rad_odbc_query(struct sql_connection *conn, char *query, int *return_count)
 }
 
 static char *
-rad_odbc_getpwd(struct sql_connection *conn, char *query)
+rad_odbc_getpwd(struct sql_connection *conn, const char *query)
 {
         ODBCconn        *odata;
         long            result;
@@ -225,7 +225,7 @@ rad_odbc_getpwd(struct sql_connection *conn, char *query)
         result = SQLFetch(stmt);
 
         if (result == SQL_SUCCESS) {
-                grad_log(L_NOTICE,
+                grad_log(GRAD_LOG_NOTICE,
                          _("query returned more tuples: %s"),
                          query);
                 SQLFreeHandle(SQL_HANDLE_STMT, stmt);
@@ -274,7 +274,7 @@ rad_odbc_n_tuples(struct sql_connection *conn, void *data, size_t *np)
 }
 
 static void *
-rad_odbc_exec(struct sql_connection *conn, char *query)
+rad_odbc_exec(struct sql_connection *conn, const char *query)
 {
 
         ODBCconn        *odata;
@@ -337,7 +337,7 @@ rad_odbc_column(void *data, size_t ncol)
         if (!data)
                 return NULL;
         if (ncol >= edata->nfields) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          _("too few columns returned (%d req'd)"), ncol);
                 return NULL;
         }
@@ -385,7 +385,7 @@ rad_odbc_free(struct sql_connection *conn, void *data)
                 return;
         
         SQLFreeHandle(SQL_HANDLE_STMT, edata->stmt);
-        grad_free(edata);
+        free(edata);
 }
 
 DECL_SQL_DISPATCH_TAB(odbc) = {
