@@ -1,12 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,
-   2006,2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -15,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -67,7 +65,7 @@ rad_postgres_reconnect(int type, struct sql_connection *conn)
                               conn->cfg->login, conn->cfg->password);
         
         if (PQstatus(pgconn) == CONNECTION_BAD) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          _("PQconnectStart failed: %s"), 
                          PQerrorMessage(pgconn));
                 PQfinish(pgconn);
@@ -91,7 +89,8 @@ rad_postgres_disconnect(struct sql_connection *conn,
 }
 
 static int
-rad_postgres_query(struct sql_connection *conn, char *query, int *return_count)
+rad_postgres_query(struct sql_connection *conn, const char *query,
+		   int *return_count)
 {
         PGresult       *res;
         ExecStatusType stat;
@@ -104,7 +103,7 @@ rad_postgres_query(struct sql_connection *conn, char *query, int *return_count)
         
         res = PQexec((PGconn*)conn->data, query);
         if (res == NULL) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          "PQexec: %s",
                          PQerrorMessage((PGconn*)conn->data));
 		if (PQstatus((PGconn*)conn->data) == CONNECTION_BAD)
@@ -148,7 +147,7 @@ rad_postgres_query(struct sql_connection *conn, char *query, int *return_count)
 		break;
 
 	default:
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          _("PQexec returned %s"),
                          PQresStatus(stat));
                 if (stat == PGRES_FATAL_ERROR 
@@ -161,7 +160,7 @@ rad_postgres_query(struct sql_connection *conn, char *query, int *return_count)
 }
 
 static char *
-rad_postgres_getpwd(struct sql_connection *conn, char *query)
+rad_postgres_getpwd(struct sql_connection *conn, const char *query)
 {
         PGresult       *res;
         ExecStatusType stat;
@@ -174,7 +173,7 @@ rad_postgres_getpwd(struct sql_connection *conn, char *query)
         
         res = PQexec((PGconn*)conn->data, query);
         if (res == NULL) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          "PQexec: %s",
                          PQerrorMessage((PGconn*)conn->data));
 		if (PQstatus((PGconn*)conn->data) == CONNECTION_BAD)
@@ -189,7 +188,7 @@ rad_postgres_getpwd(struct sql_connection *conn, char *query)
         if (stat == PGRES_TUPLES_OK) {
                 int ntuples = PQntuples(res);
                 if (ntuples > 1 && PQnfields(res)) {
-                        grad_log(L_NOTICE,
+                        grad_log(GRAD_LOG_NOTICE,
 			         ngettext("query returned %d tuple: %s",
 				  	  "query returned %d tuples: %s",
 					  ntuples),
@@ -198,7 +197,7 @@ rad_postgres_getpwd(struct sql_connection *conn, char *query)
                         return_passwd = grad_estrdup(PQgetvalue(res, 0, 0));
                 }
         } else {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          _("PQexec returned %s"),
                          PQresStatus(stat));
                 if (stat == PGRES_FATAL_ERROR
@@ -237,7 +236,7 @@ rad_postgres_n_tuples(struct sql_connection *conn, void *data, size_t *np)
 }
 
 static void *
-rad_postgres_exec(struct sql_connection *conn, char *query)
+rad_postgres_exec(struct sql_connection *conn, const char *query)
 {
         PGresult       *res;
         ExecStatusType stat;
@@ -250,7 +249,7 @@ rad_postgres_exec(struct sql_connection *conn, char *query)
         
         res = PQexec((PGconn*)conn->data, query);
         if (res == NULL) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          "PQexec: %s",
                          PQerrorMessage((PGconn*)conn->data));
 		if (PQstatus((PGconn*)conn->data) == CONNECTION_BAD)
@@ -265,7 +264,7 @@ rad_postgres_exec(struct sql_connection *conn, char *query)
         if (stat != PGRES_TUPLES_OK) {
                 PQclear(res);
                 if (stat == PGRES_FATAL_ERROR) {
-			grad_log(L_ERR,
+			grad_log(GRAD_LOG_ERR,
 			         _("PQexec returned %s"),
 			         PQresStatus(stat));
 			if (PQstatus((PGconn*)conn->data) == CONNECTION_BAD)
@@ -318,7 +317,7 @@ rad_postgres_free(struct sql_connection *conn, void *data)
                 return;
         
         PQclear(edata->res);
-        grad_free(edata);
+        free(edata);
 }
 
 DECL_SQL_DISPATCH_TAB(postgres) = {
